PRAGMA foreign_keys=OFF;
BEGIN TRANSACTION;
CREATE TABLE experiment_run (
      run_id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
      created TEXT NOT NULL,
      modified TEXT NOT NULL,
      start INTEGER NOT NULL,
      finish INTEGER,
      chunk_unit TEXT NOT NULL,
      chunk_size INTEGER NOT NULL,
      completed INTEGER NOT NULL,
      total INTEGER NOT NULL,
      failed INTEGER NOT NULL,
      queuing INTEGER NOT NULL,
      running INTEGER NOT NULL,
      submitted INTEGER NOT NULL,
      suspended INTEGER NOT NULL DEFAULT 0,
      metadata TEXT
      );
INSERT INTO experiment_run VALUES(1,'2023-05-31-10:41:24','2023-05-31-10:41:52',1685522484,1685522512,'month',4,0,21,0,0,0,0,0,'{"platforms": {"moore": {"QUEUE": "serial", "PROJECT": "Earth", "SCRATCH_DIR": "/esarchive/scratch", "HOST": "moore", "USER": "", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "false"}, "ecmwf-cca": {"QUEUE": "np", "PROCESSORS_PER_NODE": "36", "PROJECT": "spesiccf", "SCRATCH_DIR": "/scratch/ms", "HOST": "cca", "VERSION": "pbs", "USER": "c3a", "TEST_SUITE": "True", "TYPE": "ecaccess", "ADD_PROJECT_TO_HOST": "false"}, "marenostrum3": {"QUEUE": "bsc_es", "PROCESSORS_PER_NODE": "16", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "mn", "TEST_SUITE": "True", "USER": "bsc32704", "TYPE": "lsf", "ADD_PROJECT_TO_HOST": "true"}, "marenostrum4": {"QUEUE": "bsc_es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "mn-bsc32", "USER": "", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "false"}, "lumi": {"QUEUE": "normal", "PROJECT": "project_465000454", "SCRATCH_DIR": "/scratch", "HOST": "lumi", "USER": "francerou", "TYPE": "slurm"}, "transfer_node": {"QUEUE": "serial", "PROJECT": "Earth", "SCRATCH_DIR": "/esarchive/scratch", "HOST": "bscearth000", "USER": "", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "false"}}, "jobs": {"OPA_2": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "DATA_NOTIFY[3:4]", "FILE": "CLEAN.sh"}, "OPA_1": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "DATA_NOTIFY[1:2]", "FILE": "CLEAN.sh"}, "LOCAL_SETUP": {"PLATFORM": "LOCAL", "FILE": "LOCAL_SETUP.sh"}, "DATA_NOTIFY": {"SPLITS": "4", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "POST.sh"}, "MODEL_EVALUATION": {"PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "OPA_1", "FILE": "LOCALPOST.sh", "WALLCLOCK": "00:05"}, "INI": {"RUNNING": "member", "DEPENDENCIES": "REMOTE_SETUP", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "FILE": "INI.sh", "WALLCLOCK": "00:05"}, "REMOTE_SETUP": {"DEPENDENCIES": "LOCAL_SETUP", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "FILE": "REMOTE_SETUP.sh", "WALLCLOCK": "00:05"}, "DATA_CONSUMER": {"PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "OPA_1", "FILE": "TRANSFER.sh"}, "SIM": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "08:00", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "INI SIM-1", "THREADS": "1", "FILE": "SIM.sh"}}, "exp": {"svn": {"HPCARCH": "LUMI", "EXPID": "a632", "PROJECT_REVISION": "", "PROJECT_URL": ""}, "git": {"HPCARCH": "LUMI", "EXPID": "a632", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "FETCH_SINGLE_BRANCH": "true", "PROJECT_SUBMODULES": "", "PROJECT_ORIGIN": ""}, "project": {"HPCARCH": "LUMI", "EXPID": "a632", "PROJECT_DESTINATION": "", "PROJECT_TYPE": "none"}, "experiment": {"RUN_ONLY_MEMBERS": "", "HPCARCH": "LUMI", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "4", "CHUNKINI": "", "NUMCHUNKS": "2", "DATELIST": "20000101", "EXPID": "a632", "MEMBERS": "fc0", "CALENDAR": "standard"}, "project_files": {"FILE_JOBS_CONF": "", "HPCARCH": "LUMI", "JOB_SCRIPTS_TYPE": "", "FILE_PROJECT_CONF": "", "EXPID": "a632"}, "rerun": {"HPCARCH": "LUMI", "CHUNKLIST": "", "EXPID": "a632", "RERUN": "FALSE"}, "local": {"EXPID": "a632", "HPCARCH": "LUMI", "PROJECT_PATH": "/esarchive/autosubmit/a62r/projj"}}, "conf": {"migrate": {"TO_USER": ""}, "mail": {"NOTIFICATIONS": "False", "TO": ""}, "storage": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "config": {"PRESUBMISSION": "FALSE", "EXPID": "a632", "TOTALJOBS": "6", "MAXWAITINGJOBS": "3", "RETRIALS": "0", "AUTOSUBMIT_VERSION": "3.15.0b", "OUTPUT": "pdf", "SAFETYSLEEPTIME": "1"}, "communications": {"API": "paramiko"}}, "proj": {"RUN": {"SIMULATION": "test-icon", "ENVIRONMENT": "CCE", "APPLICATION": "none", "MODEL_VERSION": "", "GRID": "r2b4", "MODEL": "icon"}}}');
INSERT INTO experiment_run VALUES(2,'2023-05-31-10:41:52','2023-05-31-10:42:03',1685522512,1685522523,'month',4,0,21,0,0,0,0,0,'{"platforms": {"moore": {"QUEUE": "serial", "PROJECT": "Earth", "SCRATCH_DIR": "/esarchive/scratch", "HOST": "moore", "USER": "", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "false"}, "ecmwf-cca": {"QUEUE": "np", "PROCESSORS_PER_NODE": "36", "PROJECT": "spesiccf", "SCRATCH_DIR": "/scratch/ms", "HOST": "cca", "VERSION": "pbs", "USER": "c3a", "TEST_SUITE": "True", "TYPE": "ecaccess", "ADD_PROJECT_TO_HOST": "false"}, "marenostrum3": {"QUEUE": "bsc_es", "PROCESSORS_PER_NODE": "16", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "mn", "TEST_SUITE": "True", "USER": "bsc32704", "TYPE": "lsf", "ADD_PROJECT_TO_HOST": "true"}, "marenostrum4": {"QUEUE": "bsc_es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "mn-bsc32", "USER": "", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "false"}, "lumi": {"QUEUE": "normal", "PROJECT": "project_465000454", "SCRATCH_DIR": "/scratch", "HOST": "lumi", "USER": "francerou", "TYPE": "slurm"}, "transfer_node": {"QUEUE": "serial", "PROJECT": "Earth", "SCRATCH_DIR": "/esarchive/scratch", "HOST": "bscearth000", "USER": "", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "false"}}, "jobs": {"OPA_2": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "DATA_NOTIFY[3:4]", "FILE": "CLEAN.sh"}, "OPA_1": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "DATA_NOTIFY[1]", "FILE": "CLEAN.sh"}, "LOCAL_SETUP": {"PLATFORM": "LOCAL", "FILE": "LOCAL_SETUP.sh"}, "DATA_NOTIFY": {"SPLITS": "4", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "POST.sh"}, "MODEL_EVALUATION": {"PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "OPA_1", "FILE": "LOCALPOST.sh", "WALLCLOCK": "00:05"}, "INI": {"RUNNING": "member", "DEPENDENCIES": "REMOTE_SETUP", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "FILE": "INI.sh", "WALLCLOCK": "00:05"}, "REMOTE_SETUP": {"DEPENDENCIES": "LOCAL_SETUP", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "FILE": "REMOTE_SETUP.sh", "WALLCLOCK": "00:05"}, "DATA_CONSUMER": {"PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "OPA_1", "FILE": "TRANSFER.sh"}, "SIM": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "08:00", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "INI SIM-1", "THREADS": "1", "FILE": "SIM.sh"}}, "exp": {"svn": {"HPCARCH": "LUMI", "EXPID": "a632", "PROJECT_REVISION": "", "PROJECT_URL": ""}, "git": {"HPCARCH": "LUMI", "EXPID": "a632", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "FETCH_SINGLE_BRANCH": "true", "PROJECT_SUBMODULES": "", "PROJECT_ORIGIN": ""}, "project": {"HPCARCH": "LUMI", "EXPID": "a632", "PROJECT_DESTINATION": "", "PROJECT_TYPE": "none"}, "experiment": {"RUN_ONLY_MEMBERS": "", "HPCARCH": "LUMI", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "4", "CHUNKINI": "", "NUMCHUNKS": "2", "DATELIST": "20000101", "EXPID": "a632", "MEMBERS": "fc0", "CALENDAR": "standard"}, "project_files": {"FILE_JOBS_CONF": "", "HPCARCH": "LUMI", "JOB_SCRIPTS_TYPE": "", "FILE_PROJECT_CONF": "", "EXPID": "a632"}, "rerun": {"HPCARCH": "LUMI", "CHUNKLIST": "", "EXPID": "a632", "RERUN": "FALSE"}, "local": {"EXPID": "a632", "HPCARCH": "LUMI", "PROJECT_PATH": "/esarchive/autosubmit/a62r/projj"}}, "conf": {"migrate": {"TO_USER": ""}, "mail": {"NOTIFICATIONS": "False", "TO": ""}, "storage": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "config": {"PRESUBMISSION": "FALSE", "EXPID": "a632", "TOTALJOBS": "6", "MAXWAITINGJOBS": "3", "RETRIALS": "0", "AUTOSUBMIT_VERSION": "3.15.0b", "OUTPUT": "pdf", "SAFETYSLEEPTIME": "1"}, "communications": {"API": "paramiko"}}, "proj": {"RUN": {"SIMULATION": "test-icon", "ENVIRONMENT": "CCE", "APPLICATION": "none", "MODEL_VERSION": "", "GRID": "r2b4", "MODEL": "icon"}}}');
INSERT INTO experiment_run VALUES(3,'2023-05-31-10:42:03','2023-05-31-10:42:19',1685522523,1685522539,'month',4,0,21,0,0,0,0,0,'{"platforms": {"moore": {"QUEUE": "serial", "PROJECT": "Earth", "SCRATCH_DIR": "/esarchive/scratch", "HOST": "moore", "USER": "", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "false"}, "ecmwf-cca": {"QUEUE": "np", "PROCESSORS_PER_NODE": "36", "PROJECT": "spesiccf", "SCRATCH_DIR": "/scratch/ms", "HOST": "cca", "VERSION": "pbs", "USER": "c3a", "TEST_SUITE": "True", "TYPE": "ecaccess", "ADD_PROJECT_TO_HOST": "false"}, "marenostrum3": {"QUEUE": "bsc_es", "PROCESSORS_PER_NODE": "16", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "mn", "TEST_SUITE": "True", "USER": "bsc32704", "TYPE": "lsf", "ADD_PROJECT_TO_HOST": "true"}, "marenostrum4": {"QUEUE": "bsc_es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "mn-bsc32", "USER": "", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "false"}, "lumi": {"QUEUE": "normal", "PROJECT": "project_465000454", "SCRATCH_DIR": "/scratch", "HOST": "lumi", "USER": "francerou", "TYPE": "slurm"}, "transfer_node": {"QUEUE": "serial", "PROJECT": "Earth", "SCRATCH_DIR": "/esarchive/scratch", "HOST": "bscearth000", "USER": "", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "false"}}, "jobs": {"OPA_2": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "DATA_NOTIFY[3:4]", "FILE": "CLEAN.sh"}, "OPA_1": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "DATA_NOTIFY[1]", "FILE": "CLEAN.sh"}, "LOCAL_SETUP": {"PLATFORM": "LOCAL", "FILE": "LOCAL_SETUP.sh"}, "DATA_NOTIFY": {"SPLITS": "4", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "POST.sh"}, "MODEL_EVALUATION": {"PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "OPA_1", "FILE": "LOCALPOST.sh", "WALLCLOCK": "00:05"}, "INI": {"RUNNING": "member", "DEPENDENCIES": "REMOTE_SETUP", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "FILE": "INI.sh", "WALLCLOCK": "00:05"}, "REMOTE_SETUP": {"DEPENDENCIES": "LOCAL_SETUP", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "FILE": "REMOTE_SETUP.sh", "WALLCLOCK": "00:05"}, "DATA_CONSUMER": {"PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "OPA_1", "FILE": "TRANSFER.sh"}, "SIM": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "08:00", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "INI SIM-1", "THREADS": "1", "FILE": "SIM.sh"}}, "exp": {"svn": {"HPCARCH": "LUMI", "EXPID": "a632", "PROJECT_REVISION": "", "PROJECT_URL": ""}, "git": {"HPCARCH": "LUMI", "EXPID": "a632", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "FETCH_SINGLE_BRANCH": "true", "PROJECT_SUBMODULES": "", "PROJECT_ORIGIN": ""}, "project": {"HPCARCH": "LUMI", "EXPID": "a632", "PROJECT_DESTINATION": "", "PROJECT_TYPE": "none"}, "experiment": {"RUN_ONLY_MEMBERS": "", "HPCARCH": "LUMI", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "4", "CHUNKINI": "", "NUMCHUNKS": "2", "DATELIST": "20000101", "EXPID": "a632", "MEMBERS": "fc0", "CALENDAR": "standard"}, "project_files": {"FILE_JOBS_CONF": "", "HPCARCH": "LUMI", "JOB_SCRIPTS_TYPE": "", "FILE_PROJECT_CONF": "", "EXPID": "a632"}, "rerun": {"HPCARCH": "LUMI", "CHUNKLIST": "", "EXPID": "a632", "RERUN": "FALSE"}, "local": {"EXPID": "a632", "HPCARCH": "LUMI", "PROJECT_PATH": "/esarchive/autosubmit/a62r/projj"}}, "conf": {"migrate": {"TO_USER": ""}, "mail": {"NOTIFICATIONS": "False", "TO": ""}, "storage": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "config": {"PRESUBMISSION": "FALSE", "EXPID": "a632", "TOTALJOBS": "6", "MAXWAITINGJOBS": "3", "RETRIALS": "0", "AUTOSUBMIT_VERSION": "3.15.0b", "OUTPUT": "pdf", "SAFETYSLEEPTIME": "1"}, "communications": {"API": "paramiko"}}, "proj": {"RUN": {"SIMULATION": "test-icon", "ENVIRONMENT": "CCE", "APPLICATION": "none", "MODEL_VERSION": "", "GRID": "r2b4", "MODEL": "icon"}}}');
INSERT INTO experiment_run VALUES(4,'2023-05-31-10:42:19','2023-05-31-10:42:34',1685522539,1685522554,'month',4,0,21,0,0,0,0,0,'{"platforms": {"moore": {"QUEUE": "serial", "PROJECT": "Earth", "SCRATCH_DIR": "/esarchive/scratch", "HOST": "moore", "USER": "", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "false"}, "ecmwf-cca": {"QUEUE": "np", "PROCESSORS_PER_NODE": "36", "PROJECT": "spesiccf", "SCRATCH_DIR": "/scratch/ms", "HOST": "cca", "VERSION": "pbs", "USER": "c3a", "TEST_SUITE": "True", "TYPE": "ecaccess", "ADD_PROJECT_TO_HOST": "false"}, "marenostrum3": {"QUEUE": "bsc_es", "PROCESSORS_PER_NODE": "16", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "mn", "TEST_SUITE": "True", "USER": "bsc32704", "TYPE": "lsf", "ADD_PROJECT_TO_HOST": "true"}, "marenostrum4": {"QUEUE": "bsc_es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "mn-bsc32", "USER": "", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "false"}, "lumi": {"QUEUE": "normal", "PROJECT": "project_465000454", "SCRATCH_DIR": "/scratch", "HOST": "lumi", "USER": "francerou", "TYPE": "slurm"}, "transfer_node": {"QUEUE": "serial", "PROJECT": "Earth", "SCRATCH_DIR": "/esarchive/scratch", "HOST": "bscearth000", "USER": "", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "false"}}, "jobs": {"OPA_2": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "DATA_NOTIFY[3:4]", "FILE": "CLEAN.sh"}, "OPA_1": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "DATA_NOTIFY[1]", "FILE": "CLEAN.sh"}, "LOCAL_SETUP": {"PLATFORM": "LOCAL", "FILE": "LOCAL_SETUP.sh"}, "DATA_NOTIFY": {"SPLITS": "4", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "POST.sh"}, "MODEL_EVALUATION": {"PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "OPA_1", "FILE": "LOCALPOST.sh", "WALLCLOCK": "00:05"}, "INI": {"RUNNING": "member", "DEPENDENCIES": "REMOTE_SETUP", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "FILE": "INI.sh", "WALLCLOCK": "00:05"}, "REMOTE_SETUP": {"DEPENDENCIES": "LOCAL_SETUP", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "FILE": "REMOTE_SETUP.sh", "WALLCLOCK": "00:05"}, "DATA_CONSUMER": {"PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "OPA_1", "FILE": "TRANSFER.sh"}, "SIM": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "08:00", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "INI SIM-1", "THREADS": "1", "FILE": "SIM.sh"}}, "exp": {"svn": {"HPCARCH": "LUMI", "EXPID": "a632", "PROJECT_REVISION": "", "PROJECT_URL": ""}, "git": {"HPCARCH": "LUMI", "EXPID": "a632", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "FETCH_SINGLE_BRANCH": "true", "PROJECT_SUBMODULES": "", "PROJECT_ORIGIN": ""}, "project": {"HPCARCH": "LUMI", "EXPID": "a632", "PROJECT_DESTINATION": "", "PROJECT_TYPE": "none"}, "experiment": {"RUN_ONLY_MEMBERS": "", "HPCARCH": "LUMI", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "4", "CHUNKINI": "", "NUMCHUNKS": "2", "DATELIST": "20000101", "EXPID": "a632", "MEMBERS": "fc0", "CALENDAR": "standard"}, "project_files": {"FILE_JOBS_CONF": "", "HPCARCH": "LUMI", "JOB_SCRIPTS_TYPE": "", "FILE_PROJECT_CONF": "", "EXPID": "a632"}, "rerun": {"HPCARCH": "LUMI", "CHUNKLIST": "", "EXPID": "a632", "RERUN": "FALSE"}, "local": {"EXPID": "a632", "HPCARCH": "LUMI", "PROJECT_PATH": "/esarchive/autosubmit/a62r/projj"}}, "conf": {"migrate": {"TO_USER": ""}, "mail": {"NOTIFICATIONS": "False", "TO": ""}, "storage": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "config": {"PRESUBMISSION": "FALSE", "EXPID": "a632", "TOTALJOBS": "6", "MAXWAITINGJOBS": "3", "RETRIALS": "0", "AUTOSUBMIT_VERSION": "3.15.0b", "OUTPUT": "pdf", "SAFETYSLEEPTIME": "1"}, "communications": {"API": "paramiko"}}, "proj": {"RUN": {"SIMULATION": "test-icon", "ENVIRONMENT": "CCE", "APPLICATION": "none", "MODEL_VERSION": "", "GRID": "r2b4", "MODEL": "icon"}}}');
INSERT INTO experiment_run VALUES(5,'2023-05-31-10:42:34','2023-05-31-10:43:00',1685522554,1685522580,'month',4,0,21,0,0,0,0,0,'{"platforms": {"moore": {"QUEUE": "serial", "PROJECT": "Earth", "SCRATCH_DIR": "/esarchive/scratch", "HOST": "moore", "USER": "", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "false"}, "ecmwf-cca": {"QUEUE": "np", "PROCESSORS_PER_NODE": "36", "PROJECT": "spesiccf", "SCRATCH_DIR": "/scratch/ms", "HOST": "cca", "VERSION": "pbs", "USER": "c3a", "TEST_SUITE": "True", "TYPE": "ecaccess", "ADD_PROJECT_TO_HOST": "false"}, "marenostrum3": {"QUEUE": "bsc_es", "PROCESSORS_PER_NODE": "16", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "mn", "TEST_SUITE": "True", "USER": "bsc32704", "TYPE": "lsf", "ADD_PROJECT_TO_HOST": "true"}, "marenostrum4": {"QUEUE": "bsc_es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "mn-bsc32", "USER": "", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "false"}, "lumi": {"QUEUE": "normal", "PROJECT": "project_465000454", "SCRATCH_DIR": "/scratch", "HOST": "lumi", "USER": "francerou", "TYPE": "slurm"}, "transfer_node": {"QUEUE": "serial", "PROJECT": "Earth", "SCRATCH_DIR": "/esarchive/scratch", "HOST": "bscearth000", "USER": "", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "false"}}, "jobs": {"OPA_2": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "DATA_NOTIFY[3:4]", "FILE": "CLEAN.sh"}, "OPA_1": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "DATA_NOTIFY[1]", "FILE": "CLEAN.sh"}, "LOCAL_SETUP": {"PLATFORM": "LOCAL", "FILE": "LOCAL_SETUP.sh"}, "DATA_NOTIFY": {"SPLITS": "4", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "POST.sh"}, "MODEL_EVALUATION": {"PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "OPA_1", "FILE": "LOCALPOST.sh", "WALLCLOCK": "00:05"}, "INI": {"RUNNING": "member", "DEPENDENCIES": "REMOTE_SETUP", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "FILE": "INI.sh", "WALLCLOCK": "00:05"}, "REMOTE_SETUP": {"DEPENDENCIES": "LOCAL_SETUP", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "FILE": "REMOTE_SETUP.sh", "WALLCLOCK": "00:05"}, "DATA_CONSUMER": {"PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "OPA_1", "FILE": "TRANSFER.sh"}, "SIM": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "08:00", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "INI SIM-1", "THREADS": "1", "FILE": "SIM.sh"}}, "exp": {"svn": {"HPCARCH": "LUMI", "EXPID": "a632", "PROJECT_REVISION": "", "PROJECT_URL": ""}, "git": {"HPCARCH": "LUMI", "EXPID": "a632", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "FETCH_SINGLE_BRANCH": "true", "PROJECT_SUBMODULES": "", "PROJECT_ORIGIN": ""}, "project": {"HPCARCH": "LUMI", "EXPID": "a632", "PROJECT_DESTINATION": "", "PROJECT_TYPE": "none"}, "experiment": {"RUN_ONLY_MEMBERS": "", "HPCARCH": "LUMI", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "4", "CHUNKINI": "", "NUMCHUNKS": "2", "DATELIST": "20000101", "EXPID": "a632", "MEMBERS": "fc0", "CALENDAR": "standard"}, "project_files": {"FILE_JOBS_CONF": "", "HPCARCH": "LUMI", "JOB_SCRIPTS_TYPE": "", "FILE_PROJECT_CONF": "", "EXPID": "a632"}, "rerun": {"HPCARCH": "LUMI", "CHUNKLIST": "", "EXPID": "a632", "RERUN": "FALSE"}, "local": {"EXPID": "a632", "HPCARCH": "LUMI", "PROJECT_PATH": "/esarchive/autosubmit/a62r/projj"}}, "conf": {"migrate": {"TO_USER": ""}, "mail": {"NOTIFICATIONS": "False", "TO": ""}, "storage": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "config": {"PRESUBMISSION": "FALSE", "EXPID": "a632", "TOTALJOBS": "6", "MAXWAITINGJOBS": "3", "RETRIALS": "0", "AUTOSUBMIT_VERSION": "3.15.0b", "OUTPUT": "pdf", "SAFETYSLEEPTIME": "1"}, "communications": {"API": "paramiko"}}, "proj": {"RUN": {"SIMULATION": "test-icon", "ENVIRONMENT": "CCE", "APPLICATION": "none", "MODEL_VERSION": "", "GRID": "r2b4", "MODEL": "icon"}}}');
INSERT INTO experiment_run VALUES(6,'2023-05-31-10:43:00','2023-05-31-10:43:12',1685522580,1685522592,'month',4,0,21,0,0,0,0,0,'{"platforms": {"moore": {"QUEUE": "serial", "PROJECT": "Earth", "SCRATCH_DIR": "/esarchive/scratch", "HOST": "moore", "USER": "", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "false"}, "ecmwf-cca": {"QUEUE": "np", "PROCESSORS_PER_NODE": "36", "PROJECT": "spesiccf", "SCRATCH_DIR": "/scratch/ms", "HOST": "cca", "VERSION": "pbs", "USER": "c3a", "TEST_SUITE": "True", "TYPE": "ecaccess", "ADD_PROJECT_TO_HOST": "false"}, "marenostrum3": {"QUEUE": "bsc_es", "PROCESSORS_PER_NODE": "16", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "mn", "TEST_SUITE": "True", "USER": "bsc32704", "TYPE": "lsf", "ADD_PROJECT_TO_HOST": "true"}, "marenostrum4": {"QUEUE": "bsc_es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "mn-bsc32", "USER": "", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "false"}, "lumi": {"QUEUE": "normal", "PROJECT": "project_465000454", "SCRATCH_DIR": "/scratch", "HOST": "lumi", "USER": "francerou", "TYPE": "slurm"}, "transfer_node": {"QUEUE": "serial", "PROJECT": "Earth", "SCRATCH_DIR": "/esarchive/scratch", "HOST": "bscearth000", "USER": "", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "false"}}, "jobs": {"OPA_2": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "DATA_NOTIFY[3:4]", "FILE": "CLEAN.sh"}, "OPA_1": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "DATA_NOTIFY", "FILE": "CLEAN.sh"}, "LOCAL_SETUP": {"PLATFORM": "LOCAL", "FILE": "LOCAL_SETUP.sh"}, "DATA_NOTIFY": {"SPLITS": "4", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "POST.sh"}, "MODEL_EVALUATION": {"PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "OPA_1", "FILE": "LOCALPOST.sh", "WALLCLOCK": "00:05"}, "INI": {"RUNNING": "member", "DEPENDENCIES": "REMOTE_SETUP", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "FILE": "INI.sh", "WALLCLOCK": "00:05"}, "REMOTE_SETUP": {"DEPENDENCIES": "LOCAL_SETUP", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "FILE": "REMOTE_SETUP.sh", "WALLCLOCK": "00:05"}, "DATA_CONSUMER": {"PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "OPA_1", "FILE": "TRANSFER.sh"}, "SIM": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "08:00", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "INI SIM-1", "THREADS": "1", "FILE": "SIM.sh"}}, "exp": {"svn": {"HPCARCH": "LUMI", "EXPID": "a632", "PROJECT_REVISION": "", "PROJECT_URL": ""}, "git": {"HPCARCH": "LUMI", "EXPID": "a632", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "FETCH_SINGLE_BRANCH": "true", "PROJECT_SUBMODULES": "", "PROJECT_ORIGIN": ""}, "project": {"HPCARCH": "LUMI", "EXPID": "a632", "PROJECT_DESTINATION": "", "PROJECT_TYPE": "none"}, "experiment": {"RUN_ONLY_MEMBERS": "", "HPCARCH": "LUMI", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "4", "CHUNKINI": "", "NUMCHUNKS": "2", "DATELIST": "20000101", "EXPID": "a632", "MEMBERS": "fc0", "CALENDAR": "standard"}, "project_files": {"FILE_JOBS_CONF": "", "HPCARCH": "LUMI", "JOB_SCRIPTS_TYPE": "", "FILE_PROJECT_CONF": "", "EXPID": "a632"}, "rerun": {"HPCARCH": "LUMI", "CHUNKLIST": "", "EXPID": "a632", "RERUN": "FALSE"}, "local": {"EXPID": "a632", "HPCARCH": "LUMI", "PROJECT_PATH": "/esarchive/autosubmit/a62r/projj"}}, "conf": {"migrate": {"TO_USER": ""}, "mail": {"NOTIFICATIONS": "False", "TO": ""}, "storage": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "config": {"PRESUBMISSION": "FALSE", "EXPID": "a632", "TOTALJOBS": "6", "MAXWAITINGJOBS": "3", "RETRIALS": "0", "AUTOSUBMIT_VERSION": "3.15.0b", "OUTPUT": "pdf", "SAFETYSLEEPTIME": "1"}, "communications": {"API": "paramiko"}}, "proj": {"RUN": {"SIMULATION": "test-icon", "ENVIRONMENT": "CCE", "APPLICATION": "none", "MODEL_VERSION": "", "GRID": "r2b4", "MODEL": "icon"}}}');
INSERT INTO experiment_run VALUES(7,'2023-05-31-10:43:12','2023-05-31-10:44:33',1685522592,1685522673,'month',4,0,21,0,0,0,0,0,'{"platforms": {"moore": {"QUEUE": "serial", "PROJECT": "Earth", "SCRATCH_DIR": "/esarchive/scratch", "HOST": "moore", "USER": "", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "false"}, "ecmwf-cca": {"QUEUE": "np", "PROCESSORS_PER_NODE": "36", "PROJECT": "spesiccf", "SCRATCH_DIR": "/scratch/ms", "HOST": "cca", "VERSION": "pbs", "USER": "c3a", "TEST_SUITE": "True", "TYPE": "ecaccess", "ADD_PROJECT_TO_HOST": "false"}, "marenostrum3": {"QUEUE": "bsc_es", "PROCESSORS_PER_NODE": "16", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "mn", "TEST_SUITE": "True", "USER": "bsc32704", "TYPE": "lsf", "ADD_PROJECT_TO_HOST": "true"}, "marenostrum4": {"QUEUE": "bsc_es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "mn-bsc32", "USER": "", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "false"}, "lumi": {"QUEUE": "normal", "PROJECT": "project_465000454", "SCRATCH_DIR": "/scratch", "HOST": "lumi", "USER": "francerou", "TYPE": "slurm"}, "transfer_node": {"QUEUE": "serial", "PROJECT": "Earth", "SCRATCH_DIR": "/esarchive/scratch", "HOST": "bscearth000", "USER": "", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "false"}}, "jobs": {"OPA_2": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "DATA_NOTIFY[3:4]", "FILE": "CLEAN.sh"}, "OPA_1": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "DATA_NOTIFY[1:2]", "FILE": "CLEAN.sh"}, "LOCAL_SETUP": {"PLATFORM": "LOCAL", "FILE": "LOCAL_SETUP.sh"}, "DATA_NOTIFY": {"SPLITS": "4", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "POST.sh"}, "MODEL_EVALUATION": {"PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "OPA_1", "FILE": "LOCALPOST.sh", "WALLCLOCK": "00:05"}, "INI": {"RUNNING": "member", "DEPENDENCIES": "REMOTE_SETUP", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "FILE": "INI.sh", "WALLCLOCK": "00:05"}, "REMOTE_SETUP": {"DEPENDENCIES": "LOCAL_SETUP", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "FILE": "REMOTE_SETUP.sh", "WALLCLOCK": "00:05"}, "DATA_CONSUMER": {"PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "OPA_1", "FILE": "TRANSFER.sh"}, "SIM": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "08:00", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "INI SIM-1", "THREADS": "1", "FILE": "SIM.sh"}}, "exp": {"svn": {"HPCARCH": "LUMI", "EXPID": "a632", "PROJECT_REVISION": "", "PROJECT_URL": ""}, "git": {"HPCARCH": "LUMI", "EXPID": "a632", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "FETCH_SINGLE_BRANCH": "true", "PROJECT_SUBMODULES": "", "PROJECT_ORIGIN": ""}, "project": {"HPCARCH": "LUMI", "EXPID": "a632", "PROJECT_DESTINATION": "", "PROJECT_TYPE": "none"}, "experiment": {"RUN_ONLY_MEMBERS": "", "HPCARCH": "LUMI", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "4", "CHUNKINI": "", "NUMCHUNKS": "2", "DATELIST": "20000101", "EXPID": "a632", "MEMBERS": "fc0", "CALENDAR": "standard"}, "project_files": {"FILE_JOBS_CONF": "", "HPCARCH": "LUMI", "JOB_SCRIPTS_TYPE": "", "FILE_PROJECT_CONF": "", "EXPID": "a632"}, "rerun": {"HPCARCH": "LUMI", "CHUNKLIST": "", "EXPID": "a632", "RERUN": "FALSE"}, "local": {"EXPID": "a632", "HPCARCH": "LUMI", "PROJECT_PATH": "/esarchive/autosubmit/a62r/projj"}}, "conf": {"migrate": {"TO_USER": ""}, "mail": {"NOTIFICATIONS": "False", "TO": ""}, "storage": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "config": {"PRESUBMISSION": "FALSE", "EXPID": "a632", "TOTALJOBS": "6", "MAXWAITINGJOBS": "3", "RETRIALS": "0", "AUTOSUBMIT_VERSION": "3.15.0b", "OUTPUT": "pdf", "SAFETYSLEEPTIME": "1"}, "communications": {"API": "paramiko"}}, "proj": {"RUN": {"SIMULATION": "test-icon", "ENVIRONMENT": "CCE", "APPLICATION": "none", "MODEL_VERSION": "", "GRID": "r2b4", "MODEL": "icon"}}}');
INSERT INTO experiment_run VALUES(8,'2023-05-31-10:44:33','2023-05-31-10:46:54',1685522673,1685522814,'month',4,0,21,0,0,0,0,0,'{"platforms": {"moore": {"QUEUE": "serial", "PROJECT": "Earth", "SCRATCH_DIR": "/esarchive/scratch", "HOST": "moore", "USER": "", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "false"}, "ecmwf-cca": {"QUEUE": "np", "PROCESSORS_PER_NODE": "36", "PROJECT": "spesiccf", "SCRATCH_DIR": "/scratch/ms", "HOST": "cca", "VERSION": "pbs", "USER": "c3a", "TEST_SUITE": "True", "TYPE": "ecaccess", "ADD_PROJECT_TO_HOST": "false"}, "marenostrum3": {"QUEUE": "bsc_es", "PROCESSORS_PER_NODE": "16", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "mn", "TEST_SUITE": "True", "USER": "bsc32704", "TYPE": "lsf", "ADD_PROJECT_TO_HOST": "true"}, "marenostrum4": {"QUEUE": "bsc_es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "mn-bsc32", "USER": "", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "false"}, "lumi": {"QUEUE": "normal", "PROJECT": "project_465000454", "SCRATCH_DIR": "/scratch", "HOST": "lumi", "USER": "francerou", "TYPE": "slurm"}, "transfer_node": {"QUEUE": "serial", "PROJECT": "Earth", "SCRATCH_DIR": "/esarchive/scratch", "HOST": "bscearth000", "USER": "", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "false"}}, "jobs": {"OPA_2": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "DATA_NOTIFY[3:4]", "FILE": "CLEAN.sh"}, "OPA_1": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "DATA_NOTIFY[1:2]", "FILE": "CLEAN.sh"}, "LOCAL_SETUP": {"PLATFORM": "LOCAL", "FILE": "LOCAL_SETUP.sh"}, "DATA_NOTIFY": {"SPLITS": "4", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "POST.sh"}, "MODEL_EVALUATION": {"PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "OPA_1", "FILE": "LOCALPOST.sh", "WALLCLOCK": "00:05"}, "INI": {"RUNNING": "member", "DEPENDENCIES": "REMOTE_SETUP", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "FILE": "INI.sh", "WALLCLOCK": "00:05"}, "REMOTE_SETUP": {"DEPENDENCIES": "LOCAL_SETUP", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "FILE": "REMOTE_SETUP.sh", "WALLCLOCK": "00:05"}, "DATA_CONSUMER": {"PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "OPA_1", "FILE": "TRANSFER.sh"}, "SIM": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "08:00", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "INI SIM-1", "THREADS": "1", "FILE": "SIM.sh"}}, "exp": {"svn": {"HPCARCH": "LUMI", "EXPID": "a632", "PROJECT_REVISION": "", "PROJECT_URL": ""}, "git": {"HPCARCH": "LUMI", "EXPID": "a632", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "FETCH_SINGLE_BRANCH": "true", "PROJECT_SUBMODULES": "", "PROJECT_ORIGIN": ""}, "project": {"HPCARCH": "LUMI", "EXPID": "a632", "PROJECT_DESTINATION": "", "PROJECT_TYPE": "none"}, "experiment": {"RUN_ONLY_MEMBERS": "", "HPCARCH": "LUMI", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "4", "CHUNKINI": "", "NUMCHUNKS": "2", "DATELIST": "20000101", "EXPID": "a632", "MEMBERS": "fc0", "CALENDAR": "standard"}, "project_files": {"FILE_JOBS_CONF": "", "HPCARCH": "LUMI", "JOB_SCRIPTS_TYPE": "", "FILE_PROJECT_CONF": "", "EXPID": "a632"}, "rerun": {"HPCARCH": "LUMI", "CHUNKLIST": "", "EXPID": "a632", "RERUN": "FALSE"}, "local": {"EXPID": "a632", "HPCARCH": "LUMI", "PROJECT_PATH": "/esarchive/autosubmit/a62r/projj"}}, "conf": {"migrate": {"TO_USER": ""}, "mail": {"NOTIFICATIONS": "False", "TO": ""}, "storage": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "config": {"PRESUBMISSION": "FALSE", "EXPID": "a632", "TOTALJOBS": "6", "MAXWAITINGJOBS": "3", "RETRIALS": "0", "AUTOSUBMIT_VERSION": "3.15.0b", "OUTPUT": "pdf", "SAFETYSLEEPTIME": "1"}, "communications": {"API": "paramiko"}}, "proj": {"RUN": {"SIMULATION": "test-icon", "ENVIRONMENT": "CCE", "APPLICATION": "none", "MODEL_VERSION": "", "GRID": "r2b4", "MODEL": "icon"}}}');
INSERT INTO experiment_run VALUES(9,'2023-05-31-10:46:54','2023-05-31-10:51:47',1685522814,1685523107,'month',4,0,21,0,0,0,0,0,'{"platforms": {"moore": {"QUEUE": "serial", "PROJECT": "Earth", "SCRATCH_DIR": "/esarchive/scratch", "HOST": "moore", "USER": "", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "false"}, "ecmwf-cca": {"QUEUE": "np", "PROCESSORS_PER_NODE": "36", "PROJECT": "spesiccf", "SCRATCH_DIR": "/scratch/ms", "HOST": "cca", "VERSION": "pbs", "USER": "c3a", "TEST_SUITE": "True", "TYPE": "ecaccess", "ADD_PROJECT_TO_HOST": "false"}, "marenostrum3": {"QUEUE": "bsc_es", "PROCESSORS_PER_NODE": "16", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "mn", "TEST_SUITE": "True", "USER": "bsc32704", "TYPE": "lsf", "ADD_PROJECT_TO_HOST": "true"}, "marenostrum4": {"QUEUE": "bsc_es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "mn-bsc32", "USER": "", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "false"}, "lumi": {"QUEUE": "normal", "PROJECT": "project_465000454", "SCRATCH_DIR": "/scratch", "HOST": "lumi", "USER": "francerou", "TYPE": "slurm"}, "transfer_node": {"QUEUE": "serial", "PROJECT": "Earth", "SCRATCH_DIR": "/esarchive/scratch", "HOST": "bscearth000", "USER": "", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "false"}}, "jobs": {"OPA_2": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "DATA_NOTIFY[3:4]", "FILE": "CLEAN.sh"}, "OPA_1": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "DATA_NOTIFY[1:2]", "FILE": "CLEAN.sh"}, "LOCAL_SETUP": {"PLATFORM": "LOCAL", "FILE": "LOCAL_SETUP.sh"}, "DATA_NOTIFY": {"SPLITS": "4", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "POST.sh"}, "MODEL_EVALUATION": {"PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "OPA_1", "FILE": "LOCALPOST.sh", "WALLCLOCK": "00:05"}, "INI": {"RUNNING": "member", "DEPENDENCIES": "REMOTE_SETUP", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "FILE": "INI.sh", "WALLCLOCK": "00:05"}, "REMOTE_SETUP": {"DEPENDENCIES": "LOCAL_SETUP", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "FILE": "REMOTE_SETUP.sh", "WALLCLOCK": "00:05"}, "DATA_CONSUMER": {"PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "OPA_1", "FILE": "TRANSFER.sh"}, "SIM": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "08:00", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "INI SIM-1", "THREADS": "1", "FILE": "SIM.sh"}}, "exp": {"svn": {"HPCARCH": "LUMI", "EXPID": "a632", "PROJECT_REVISION": "", "PROJECT_URL": ""}, "git": {"HPCARCH": "LUMI", "EXPID": "a632", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "FETCH_SINGLE_BRANCH": "true", "PROJECT_SUBMODULES": "", "PROJECT_ORIGIN": ""}, "project": {"HPCARCH": "LUMI", "EXPID": "a632", "PROJECT_DESTINATION": "", "PROJECT_TYPE": "none"}, "experiment": {"RUN_ONLY_MEMBERS": "", "HPCARCH": "LUMI", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "4", "CHUNKINI": "", "NUMCHUNKS": "2", "DATELIST": "20000101", "EXPID": "a632", "MEMBERS": "fc0", "CALENDAR": "standard"}, "project_files": {"FILE_JOBS_CONF": "", "HPCARCH": "LUMI", "JOB_SCRIPTS_TYPE": "", "FILE_PROJECT_CONF": "", "EXPID": "a632"}, "rerun": {"HPCARCH": "LUMI", "CHUNKLIST": "", "EXPID": "a632", "RERUN": "FALSE"}, "local": {"EXPID": "a632", "HPCARCH": "LUMI", "PROJECT_PATH": "/esarchive/autosubmit/a62r/projj"}}, "conf": {"migrate": {"TO_USER": ""}, "mail": {"NOTIFICATIONS": "False", "TO": ""}, "storage": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "config": {"PRESUBMISSION": "FALSE", "EXPID": "a632", "TOTALJOBS": "6", "MAXWAITINGJOBS": "3", "RETRIALS": "0", "AUTOSUBMIT_VERSION": "3.15.0b", "OUTPUT": "pdf", "SAFETYSLEEPTIME": "1"}, "communications": {"API": "paramiko"}}, "proj": {"RUN": {"SIMULATION": "test-icon", "ENVIRONMENT": "CCE", "APPLICATION": "none", "MODEL_VERSION": "", "GRID": "r2b4", "MODEL": "icon"}}}');
INSERT INTO experiment_run VALUES(10,'2023-05-31-10:51:47','2023-05-31-10:52:22',1685523107,1685523142,'month',4,0,21,0,0,0,0,0,'{"platforms": {"moore": {"QUEUE": "serial", "PROJECT": "Earth", "SCRATCH_DIR": "/esarchive/scratch", "HOST": "moore", "USER": "", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "false"}, "ecmwf-cca": {"QUEUE": "np", "PROCESSORS_PER_NODE": "36", "PROJECT": "spesiccf", "SCRATCH_DIR": "/scratch/ms", "HOST": "cca", "VERSION": "pbs", "USER": "c3a", "TEST_SUITE": "True", "TYPE": "ecaccess", "ADD_PROJECT_TO_HOST": "false"}, "marenostrum3": {"QUEUE": "bsc_es", "PROCESSORS_PER_NODE": "16", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "mn", "TEST_SUITE": "True", "USER": "bsc32704", "TYPE": "lsf", "ADD_PROJECT_TO_HOST": "true"}, "marenostrum4": {"QUEUE": "bsc_es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "mn-bsc32", "USER": "", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "false"}, "lumi": {"QUEUE": "normal", "PROJECT": "project_465000454", "SCRATCH_DIR": "/scratch", "HOST": "lumi", "USER": "francerou", "TYPE": "slurm"}, "transfer_node": {"QUEUE": "serial", "PROJECT": "Earth", "SCRATCH_DIR": "/esarchive/scratch", "HOST": "bscearth000", "USER": "", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "false"}}, "jobs": {"OPA_2": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "DATA_NOTIFY[3:4]", "FILE": "CLEAN.sh"}, "OPA_1": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "DATA_NOTIFY[1:2]", "FILE": "CLEAN.sh"}, "LOCAL_SETUP": {"PLATFORM": "LOCAL", "FILE": "LOCAL_SETUP.sh"}, "DATA_NOTIFY": {"SPLITS": "4", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "POST.sh"}, "MODEL_EVALUATION": {"PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "OPA_1", "FILE": "LOCALPOST.sh", "WALLCLOCK": "00:05"}, "INI": {"RUNNING": "member", "DEPENDENCIES": "REMOTE_SETUP", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "FILE": "INI.sh", "WALLCLOCK": "00:05"}, "REMOTE_SETUP": {"DEPENDENCIES": "LOCAL_SETUP", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "FILE": "REMOTE_SETUP.sh", "WALLCLOCK": "00:05"}, "DATA_CONSUMER": {"PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "OPA_1", "FILE": "TRANSFER.sh"}, "SIM": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "08:00", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "INI SIM-1", "THREADS": "1", "FILE": "SIM.sh"}}, "exp": {"svn": {"HPCARCH": "LUMI", "EXPID": "a632", "PROJECT_REVISION": "", "PROJECT_URL": ""}, "git": {"HPCARCH": "LUMI", "EXPID": "a632", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "FETCH_SINGLE_BRANCH": "true", "PROJECT_SUBMODULES": "", "PROJECT_ORIGIN": ""}, "project": {"HPCARCH": "LUMI", "EXPID": "a632", "PROJECT_DESTINATION": "", "PROJECT_TYPE": "none"}, "experiment": {"RUN_ONLY_MEMBERS": "", "HPCARCH": "LUMI", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "4", "CHUNKINI": "", "NUMCHUNKS": "2", "DATELIST": "20000101", "EXPID": "a632", "MEMBERS": "fc0", "CALENDAR": "standard"}, "project_files": {"FILE_JOBS_CONF": "", "HPCARCH": "LUMI", "JOB_SCRIPTS_TYPE": "", "FILE_PROJECT_CONF": "", "EXPID": "a632"}, "rerun": {"HPCARCH": "LUMI", "CHUNKLIST": "", "EXPID": "a632", "RERUN": "FALSE"}, "local": {"EXPID": "a632", "HPCARCH": "LUMI", "PROJECT_PATH": "/esarchive/autosubmit/a62r/projj"}}, "conf": {"migrate": {"TO_USER": ""}, "mail": {"NOTIFICATIONS": "False", "TO": ""}, "storage": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "config": {"PRESUBMISSION": "FALSE", "EXPID": "a632", "TOTALJOBS": "6", "MAXWAITINGJOBS": "3", "RETRIALS": "0", "AUTOSUBMIT_VERSION": "3.15.0b", "OUTPUT": "pdf", "SAFETYSLEEPTIME": "1"}, "communications": {"API": "paramiko"}}, "proj": {"RUN": {"SIMULATION": "test-icon", "ENVIRONMENT": "CCE", "APPLICATION": "none", "MODEL_VERSION": "", "GRID": "r2b4", "MODEL": "icon"}}}');
INSERT INTO experiment_run VALUES(11,'2023-05-31-10:52:22','2023-05-31-10:52:42',1685523142,1685523162,'month',4,0,21,0,0,0,0,0,'{"platforms": {"moore": {"QUEUE": "serial", "PROJECT": "Earth", "SCRATCH_DIR": "/esarchive/scratch", "HOST": "moore", "USER": "", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "false"}, "ecmwf-cca": {"QUEUE": "np", "PROCESSORS_PER_NODE": "36", "PROJECT": "spesiccf", "SCRATCH_DIR": "/scratch/ms", "HOST": "cca", "VERSION": "pbs", "USER": "c3a", "TEST_SUITE": "True", "TYPE": "ecaccess", "ADD_PROJECT_TO_HOST": "false"}, "marenostrum3": {"QUEUE": "bsc_es", "PROCESSORS_PER_NODE": "16", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "mn", "TEST_SUITE": "True", "USER": "bsc32704", "TYPE": "lsf", "ADD_PROJECT_TO_HOST": "true"}, "marenostrum4": {"QUEUE": "bsc_es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "mn-bsc32", "USER": "", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "false"}, "lumi": {"QUEUE": "normal", "PROJECT": "project_465000454", "SCRATCH_DIR": "/scratch", "HOST": "lumi", "USER": "francerou", "TYPE": "slurm"}, "transfer_node": {"QUEUE": "serial", "PROJECT": "Earth", "SCRATCH_DIR": "/esarchive/scratch", "HOST": "bscearth000", "USER": "", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "false"}}, "jobs": {"OPA_2": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "DATA_NOTIFY[3:4]", "FILE": "CLEAN.sh"}, "OPA_1": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "DATA_NOTIFY[1:2]", "FILE": "CLEAN.sh"}, "LOCAL_SETUP": {"PLATFORM": "LOCAL", "FILE": "LOCAL_SETUP.sh"}, "DATA_NOTIFY": {"SPLITS": "4", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "POST.sh"}, "MODEL_EVALUATION": {"PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "OPA_1", "FILE": "LOCALPOST.sh", "WALLCLOCK": "00:05"}, "INI": {"RUNNING": "member", "DEPENDENCIES": "REMOTE_SETUP", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "FILE": "INI.sh", "WALLCLOCK": "00:05"}, "REMOTE_SETUP": {"DEPENDENCIES": "LOCAL_SETUP", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "FILE": "REMOTE_SETUP.sh", "WALLCLOCK": "00:05"}, "DATA_CONSUMER": {"PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "OPA_1", "FILE": "TRANSFER.sh"}, "SIM": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "08:00", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "INI SIM-1", "THREADS": "1", "FILE": "SIM.sh"}}, "exp": {"svn": {"HPCARCH": "LUMI", "EXPID": "a632", "PROJECT_REVISION": "", "PROJECT_URL": ""}, "git": {"HPCARCH": "LUMI", "EXPID": "a632", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "FETCH_SINGLE_BRANCH": "true", "PROJECT_SUBMODULES": "", "PROJECT_ORIGIN": ""}, "project": {"HPCARCH": "LUMI", "EXPID": "a632", "PROJECT_DESTINATION": "", "PROJECT_TYPE": "none"}, "experiment": {"RUN_ONLY_MEMBERS": "", "HPCARCH": "LUMI", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "4", "CHUNKINI": "", "NUMCHUNKS": "2", "DATELIST": "20000101", "EXPID": "a632", "MEMBERS": "fc0", "CALENDAR": "standard"}, "project_files": {"FILE_JOBS_CONF": "", "HPCARCH": "LUMI", "JOB_SCRIPTS_TYPE": "", "FILE_PROJECT_CONF": "", "EXPID": "a632"}, "rerun": {"HPCARCH": "LUMI", "CHUNKLIST": "", "EXPID": "a632", "RERUN": "FALSE"}, "local": {"EXPID": "a632", "HPCARCH": "LUMI", "PROJECT_PATH": "/esarchive/autosubmit/a62r/projj"}}, "conf": {"migrate": {"TO_USER": ""}, "mail": {"NOTIFICATIONS": "False", "TO": ""}, "storage": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "config": {"PRESUBMISSION": "FALSE", "EXPID": "a632", "TOTALJOBS": "6", "MAXWAITINGJOBS": "3", "RETRIALS": "0", "AUTOSUBMIT_VERSION": "3.15.0b", "OUTPUT": "pdf", "SAFETYSLEEPTIME": "1"}, "communications": {"API": "paramiko"}}, "proj": {"RUN": {"SIMULATION": "test-icon", "ENVIRONMENT": "CCE", "APPLICATION": "none", "MODEL_VERSION": "", "GRID": "r2b4", "MODEL": "icon"}}}');
INSERT INTO experiment_run VALUES(12,'2023-05-31-10:52:42','2023-05-31-12:00:24',1685523162,1685527224,'month',4,0,21,0,0,0,0,0,'{"platforms": {"moore": {"QUEUE": "serial", "PROJECT": "Earth", "SCRATCH_DIR": "/esarchive/scratch", "HOST": "moore", "USER": "", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "false"}, "ecmwf-cca": {"QUEUE": "np", "PROCESSORS_PER_NODE": "36", "PROJECT": "spesiccf", "SCRATCH_DIR": "/scratch/ms", "HOST": "cca", "VERSION": "pbs", "USER": "c3a", "TEST_SUITE": "True", "TYPE": "ecaccess", "ADD_PROJECT_TO_HOST": "false"}, "marenostrum3": {"QUEUE": "bsc_es", "PROCESSORS_PER_NODE": "16", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "mn", "TEST_SUITE": "True", "USER": "bsc32704", "TYPE": "lsf", "ADD_PROJECT_TO_HOST": "true"}, "marenostrum4": {"QUEUE": "bsc_es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "mn-bsc32", "USER": "", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "false"}, "lumi": {"QUEUE": "normal", "PROJECT": "project_465000454", "SCRATCH_DIR": "/scratch", "HOST": "lumi", "USER": "francerou", "TYPE": "slurm"}, "transfer_node": {"QUEUE": "serial", "PROJECT": "Earth", "SCRATCH_DIR": "/esarchive/scratch", "HOST": "bscearth000", "USER": "", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "false"}}, "jobs": {"OPA_2": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "DATA_NOTIFY[3:4]", "FILE": "CLEAN.sh"}, "OPA_1": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "DATA_NOTIFY[1:2]", "FILE": "CLEAN.sh"}, "LOCAL_SETUP": {"PLATFORM": "LOCAL", "FILE": "LOCAL_SETUP.sh"}, "DATA_NOTIFY": {"SPLITS": "4", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "POST.sh"}, "MODEL_EVALUATION": {"PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "OPA_1", "FILE": "LOCALPOST.sh", "WALLCLOCK": "00:05"}, "INI": {"RUNNING": "member", "DEPENDENCIES": "REMOTE_SETUP", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "FILE": "INI.sh", "WALLCLOCK": "00:05"}, "REMOTE_SETUP": {"DEPENDENCIES": "LOCAL_SETUP", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "FILE": "REMOTE_SETUP.sh", "WALLCLOCK": "00:05"}, "DATA_CONSUMER": {"PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "OPA_1", "FILE": "TRANSFER.sh"}, "SIM": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "08:00", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "INI SIM-1", "THREADS": "1", "FILE": "SIM.sh"}}, "exp": {"svn": {"HPCARCH": "LUMI", "EXPID": "a632", "PROJECT_REVISION": "", "PROJECT_URL": ""}, "git": {"HPCARCH": "LUMI", "EXPID": "a632", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "FETCH_SINGLE_BRANCH": "true", "PROJECT_SUBMODULES": "", "PROJECT_ORIGIN": ""}, "project": {"HPCARCH": "LUMI", "EXPID": "a632", "PROJECT_DESTINATION": "", "PROJECT_TYPE": "none"}, "experiment": {"RUN_ONLY_MEMBERS": "", "HPCARCH": "LUMI", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "4", "CHUNKINI": "", "NUMCHUNKS": "2", "DATELIST": "20000101", "EXPID": "a632", "MEMBERS": "fc0", "CALENDAR": "standard"}, "project_files": {"FILE_JOBS_CONF": "", "HPCARCH": "LUMI", "JOB_SCRIPTS_TYPE": "", "FILE_PROJECT_CONF": "", "EXPID": "a632"}, "rerun": {"HPCARCH": "LUMI", "CHUNKLIST": "", "EXPID": "a632", "RERUN": "FALSE"}, "local": {"EXPID": "a632", "HPCARCH": "LUMI", "PROJECT_PATH": "/esarchive/autosubmit/a62r/projj"}}, "conf": {"migrate": {"TO_USER": ""}, "mail": {"NOTIFICATIONS": "False", "TO": ""}, "storage": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "config": {"PRESUBMISSION": "FALSE", "EXPID": "a632", "TOTALJOBS": "6", "MAXWAITINGJOBS": "3", "RETRIALS": "0", "AUTOSUBMIT_VERSION": "3.15.0b", "OUTPUT": "pdf", "SAFETYSLEEPTIME": "1"}, "communications": {"API": "paramiko"}}, "proj": {"RUN": {"SIMULATION": "test-icon", "ENVIRONMENT": "CCE", "APPLICATION": "none", "MODEL_VERSION": "", "GRID": "r2b4", "MODEL": "icon"}}}');
INSERT INTO experiment_run VALUES(13,'2023-05-31-12:00:24','2023-05-31-12:01:15',1685527224,1685527275,'month',4,0,27,0,0,0,0,0,'{"platforms": {"moore": {"QUEUE": "serial", "PROJECT": "Earth", "SCRATCH_DIR": "/esarchive/scratch", "HOST": "moore", "USER": "", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "false"}, "ecmwf-cca": {"QUEUE": "np", "PROCESSORS_PER_NODE": "36", "PROJECT": "spesiccf", "SCRATCH_DIR": "/scratch/ms", "HOST": "cca", "VERSION": "pbs", "USER": "c3a", "TEST_SUITE": "True", "TYPE": "ecaccess", "ADD_PROJECT_TO_HOST": "false"}, "marenostrum3": {"QUEUE": "bsc_es", "PROCESSORS_PER_NODE": "16", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "mn", "TEST_SUITE": "True", "USER": "bsc32704", "TYPE": "lsf", "ADD_PROJECT_TO_HOST": "true"}, "marenostrum4": {"QUEUE": "bsc_es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "mn-bsc32", "USER": "", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "false"}, "lumi": {"QUEUE": "normal", "PROJECT": "project_465000454", "SCRATCH_DIR": "/scratch", "HOST": "lumi", "USER": "francerou", "TYPE": "slurm"}, "transfer_node": {"QUEUE": "serial", "PROJECT": "Earth", "SCRATCH_DIR": "/esarchive/scratch", "HOST": "bscearth000", "USER": "", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "false"}}, "jobs": {"OPA_2_2": {"EXCLUDE_CHUNKS": "1", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "DATA_NOTIFY[3:4]", "FILE": "CLEAN.sh"}, "OPA_2_1": {"EXCLUDE_CHUNKS": "1", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "DATA_NOTIFY[1:2]", "FILE": "CLEAN.sh"}, "LOCAL_SETUP": {"PLATFORM": "LOCAL", "FILE": "LOCAL_SETUP.sh"}, "DATA_NOTIFY": {"SPLITS": "4", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "POST.sh"}, "OPA_1_1": {"EXCLUDE_CHUNKS": "2", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "DATA_NOTIFY[1:2]", "FILE": "CLEAN.sh"}, "OPA_1_2": {"EXCLUDE_CHUNKS": "2", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "DATA_NOTIFY[3:4]", "FILE": "CLEAN.sh"}, "MODEL_EVALUATION": {"PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "OPA_1_1", "FILE": "LOCALPOST.sh", "WALLCLOCK": "00:05"}, "INI": {"RUNNING": "member", "DEPENDENCIES": "REMOTE_SETUP", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "FILE": "INI.sh", "WALLCLOCK": "00:05"}, "REMOTE_SETUP": {"DEPENDENCIES": "LOCAL_SETUP", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "FILE": "REMOTE_SETUP.sh", "WALLCLOCK": "00:05"}, "DATA_CONSUMER_DN": {"EXCLUDE_CHUNKS": "1", "RUNNING": "chunk", "DEPENDENCIES": "DATA_NOTIFY", "FILE": "TRANSFER.sh", "PLATFORM": "LOCAL"}, "SIM": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "08:00", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "INI SIM-1", "THREADS": "1", "FILE": "SIM.sh"}, "DATA_CONSUMER_OPA": {"PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "OPA_1_1", "FILE": "TRANSFER.sh"}}, "exp": {"svn": {"HPCARCH": "LUMI", "EXPID": "a632", "PROJECT_REVISION": "", "PROJECT_URL": ""}, "git": {"HPCARCH": "LUMI", "EXPID": "a632", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "FETCH_SINGLE_BRANCH": "true", "PROJECT_SUBMODULES": "", "PROJECT_ORIGIN": ""}, "project": {"HPCARCH": "LUMI", "EXPID": "a632", "PROJECT_DESTINATION": "", "PROJECT_TYPE": "none"}, "experiment": {"RUN_ONLY_MEMBERS": "", "HPCARCH": "LUMI", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "4", "CHUNKINI": "", "NUMCHUNKS": "2", "DATELIST": "20000101", "EXPID": "a632", "MEMBERS": "fc0", "CALENDAR": "standard"}, "project_files": {"FILE_JOBS_CONF": "", "HPCARCH": "LUMI", "JOB_SCRIPTS_TYPE": "", "FILE_PROJECT_CONF": "", "EXPID": "a632"}, "rerun": {"HPCARCH": "LUMI", "CHUNKLIST": "", "EXPID": "a632", "RERUN": "FALSE"}, "local": {"EXPID": "a632", "HPCARCH": "LUMI", "PROJECT_PATH": "/esarchive/autosubmit/a62r/projj"}}, "conf": {"migrate": {"TO_USER": ""}, "mail": {"NOTIFICATIONS": "False", "TO": ""}, "storage": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "config": {"PRESUBMISSION": "FALSE", "EXPID": "a632", "TOTALJOBS": "6", "MAXWAITINGJOBS": "3", "RETRIALS": "0", "AUTOSUBMIT_VERSION": "3.15.0b", "OUTPUT": "pdf", "SAFETYSLEEPTIME": "1"}, "communications": {"API": "paramiko"}}, "proj": {"RUN": {"SIMULATION": "test-icon", "ENVIRONMENT": "CCE", "APPLICATION": "none", "MODEL_VERSION": "", "GRID": "r2b4", "MODEL": "icon"}}}');
INSERT INTO experiment_run VALUES(14,'2023-05-31-12:01:15','2023-05-31-12:01:35',1685527275,1685527295,'month',4,0,27,0,0,0,0,0,'{"platforms": {"moore": {"QUEUE": "serial", "PROJECT": "Earth", "SCRATCH_DIR": "/esarchive/scratch", "HOST": "moore", "USER": "", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "false"}, "ecmwf-cca": {"QUEUE": "np", "PROCESSORS_PER_NODE": "36", "PROJECT": "spesiccf", "SCRATCH_DIR": "/scratch/ms", "HOST": "cca", "VERSION": "pbs", "USER": "c3a", "TEST_SUITE": "True", "TYPE": "ecaccess", "ADD_PROJECT_TO_HOST": "false"}, "marenostrum3": {"QUEUE": "bsc_es", "PROCESSORS_PER_NODE": "16", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "mn", "TEST_SUITE": "True", "USER": "bsc32704", "TYPE": "lsf", "ADD_PROJECT_TO_HOST": "true"}, "marenostrum4": {"QUEUE": "bsc_es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "mn-bsc32", "USER": "", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "false"}, "lumi": {"QUEUE": "normal", "PROJECT": "project_465000454", "SCRATCH_DIR": "/scratch", "HOST": "lumi", "USER": "francerou", "TYPE": "slurm"}, "transfer_node": {"QUEUE": "serial", "PROJECT": "Earth", "SCRATCH_DIR": "/esarchive/scratch", "HOST": "bscearth000", "USER": "", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "false"}}, "jobs": {"OPA_2_2": {"EXCLUDE_CHUNKS": "1", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "DATA_NOTIFY[3:4]", "FILE": "CLEAN.sh"}, "OPA_2_1": {"EXCLUDE_CHUNKS": "0", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "DATA_NOTIFY[1:2]", "FILE": "CLEAN.sh"}, "LOCAL_SETUP": {"PLATFORM": "LOCAL", "FILE": "LOCAL_SETUP.sh"}, "DATA_NOTIFY": {"SPLITS": "4", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "POST.sh"}, "OPA_1_1": {"EXCLUDE_CHUNKS": "2", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "DATA_NOTIFY[1:2]", "FILE": "CLEAN.sh"}, "OPA_1_2": {"EXCLUDE_CHUNKS": "2", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "DATA_NOTIFY[3:4]", "FILE": "CLEAN.sh"}, "MODEL_EVALUATION": {"PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "OPA_1_1", "FILE": "LOCALPOST.sh", "WALLCLOCK": "00:05"}, "INI": {"RUNNING": "member", "DEPENDENCIES": "REMOTE_SETUP", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "FILE": "INI.sh", "WALLCLOCK": "00:05"}, "REMOTE_SETUP": {"DEPENDENCIES": "LOCAL_SETUP", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "FILE": "REMOTE_SETUP.sh", "WALLCLOCK": "00:05"}, "DATA_CONSUMER_DN": {"EXCLUDE_CHUNKS": "1", "RUNNING": "chunk", "DEPENDENCIES": "DATA_NOTIFY", "FILE": "TRANSFER.sh", "PLATFORM": "LOCAL"}, "SIM": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "08:00", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "INI SIM-1", "THREADS": "1", "FILE": "SIM.sh"}, "DATA_CONSUMER_OPA": {"PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "OPA_1_1", "FILE": "TRANSFER.sh"}}, "exp": {"svn": {"HPCARCH": "LUMI", "EXPID": "a632", "PROJECT_REVISION": "", "PROJECT_URL": ""}, "git": {"HPCARCH": "LUMI", "EXPID": "a632", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "FETCH_SINGLE_BRANCH": "true", "PROJECT_SUBMODULES": "", "PROJECT_ORIGIN": ""}, "project": {"HPCARCH": "LUMI", "EXPID": "a632", "PROJECT_DESTINATION": "", "PROJECT_TYPE": "none"}, "experiment": {"RUN_ONLY_MEMBERS": "", "HPCARCH": "LUMI", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "4", "CHUNKINI": "", "NUMCHUNKS": "2", "DATELIST": "20000101", "EXPID": "a632", "MEMBERS": "fc0", "CALENDAR": "standard"}, "project_files": {"FILE_JOBS_CONF": "", "HPCARCH": "LUMI", "JOB_SCRIPTS_TYPE": "", "FILE_PROJECT_CONF": "", "EXPID": "a632"}, "rerun": {"HPCARCH": "LUMI", "CHUNKLIST": "", "EXPID": "a632", "RERUN": "FALSE"}, "local": {"EXPID": "a632", "HPCARCH": "LUMI", "PROJECT_PATH": "/esarchive/autosubmit/a62r/projj"}}, "conf": {"migrate": {"TO_USER": ""}, "mail": {"NOTIFICATIONS": "False", "TO": ""}, "storage": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "config": {"PRESUBMISSION": "FALSE", "EXPID": "a632", "TOTALJOBS": "6", "MAXWAITINGJOBS": "3", "RETRIALS": "0", "AUTOSUBMIT_VERSION": "3.15.0b", "OUTPUT": "pdf", "SAFETYSLEEPTIME": "1"}, "communications": {"API": "paramiko"}}, "proj": {"RUN": {"SIMULATION": "test-icon", "ENVIRONMENT": "CCE", "APPLICATION": "none", "MODEL_VERSION": "", "GRID": "r2b4", "MODEL": "icon"}}}');
INSERT INTO experiment_run VALUES(15,'2023-05-31-12:01:35','2023-05-31-12:02:23',1685527295,1685527343,'month',4,0,27,0,0,0,0,0,'{"platforms": {"moore": {"QUEUE": "serial", "PROJECT": "Earth", "SCRATCH_DIR": "/esarchive/scratch", "HOST": "moore", "USER": "", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "false"}, "ecmwf-cca": {"QUEUE": "np", "PROCESSORS_PER_NODE": "36", "PROJECT": "spesiccf", "SCRATCH_DIR": "/scratch/ms", "HOST": "cca", "VERSION": "pbs", "USER": "c3a", "TEST_SUITE": "True", "TYPE": "ecaccess", "ADD_PROJECT_TO_HOST": "false"}, "marenostrum3": {"QUEUE": "bsc_es", "PROCESSORS_PER_NODE": "16", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "mn", "TEST_SUITE": "True", "USER": "bsc32704", "TYPE": "lsf", "ADD_PROJECT_TO_HOST": "true"}, "marenostrum4": {"QUEUE": "bsc_es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "mn-bsc32", "USER": "", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "false"}, "lumi": {"QUEUE": "normal", "PROJECT": "project_465000454", "SCRATCH_DIR": "/scratch", "HOST": "lumi", "USER": "francerou", "TYPE": "slurm"}, "transfer_node": {"QUEUE": "serial", "PROJECT": "Earth", "SCRATCH_DIR": "/esarchive/scratch", "HOST": "bscearth000", "USER": "", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "false"}}, "jobs": {"OPA_2_2": {"EXCLUDE_CHUNKS": "1", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "DATA_NOTIFY[3:4]", "FILE": "CLEAN.sh"}, "OPA_2_1": {"EXCLUDE_CHUNKS": "1", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "FILE": "CLEAN.sh"}, "LOCAL_SETUP": {"PLATFORM": "LOCAL", "FILE": "LOCAL_SETUP.sh"}, "DATA_NOTIFY": {"SPLITS": "4", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "POST.sh"}, "OPA_1_1": {"EXCLUDE_CHUNKS": "2", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "DATA_NOTIFY[1:2]", "FILE": "CLEAN.sh"}, "OPA_1_2": {"EXCLUDE_CHUNKS": "2", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "DATA_NOTIFY[3:4]", "FILE": "CLEAN.sh"}, "MODEL_EVALUATION": {"PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "OPA_1_1", "FILE": "LOCALPOST.sh", "WALLCLOCK": "00:05"}, "INI": {"RUNNING": "member", "DEPENDENCIES": "REMOTE_SETUP", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "FILE": "INI.sh", "WALLCLOCK": "00:05"}, "REMOTE_SETUP": {"DEPENDENCIES": "LOCAL_SETUP", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "FILE": "REMOTE_SETUP.sh", "WALLCLOCK": "00:05"}, "DATA_CONSUMER_DN": {"EXCLUDE_CHUNKS": "1", "RUNNING": "chunk", "DEPENDENCIES": "DATA_NOTIFY", "FILE": "TRANSFER.sh", "PLATFORM": "LOCAL"}, "SIM": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "08:00", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "INI SIM-1", "THREADS": "1", "FILE": "SIM.sh"}, "DATA_CONSUMER_OPA": {"PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "OPA_1_1", "FILE": "TRANSFER.sh"}}, "exp": {"svn": {"HPCARCH": "LUMI", "EXPID": "a632", "PROJECT_REVISION": "", "PROJECT_URL": ""}, "git": {"HPCARCH": "LUMI", "EXPID": "a632", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "FETCH_SINGLE_BRANCH": "true", "PROJECT_SUBMODULES": "", "PROJECT_ORIGIN": ""}, "project": {"HPCARCH": "LUMI", "EXPID": "a632", "PROJECT_DESTINATION": "", "PROJECT_TYPE": "none"}, "experiment": {"RUN_ONLY_MEMBERS": "", "HPCARCH": "LUMI", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "4", "CHUNKINI": "", "NUMCHUNKS": "2", "DATELIST": "20000101", "EXPID": "a632", "MEMBERS": "fc0", "CALENDAR": "standard"}, "project_files": {"FILE_JOBS_CONF": "", "HPCARCH": "LUMI", "JOB_SCRIPTS_TYPE": "", "FILE_PROJECT_CONF": "", "EXPID": "a632"}, "rerun": {"HPCARCH": "LUMI", "CHUNKLIST": "", "EXPID": "a632", "RERUN": "FALSE"}, "local": {"EXPID": "a632", "HPCARCH": "LUMI", "PROJECT_PATH": "/esarchive/autosubmit/a62r/projj"}}, "conf": {"migrate": {"TO_USER": ""}, "mail": {"NOTIFICATIONS": "False", "TO": ""}, "storage": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "config": {"PRESUBMISSION": "FALSE", "EXPID": "a632", "TOTALJOBS": "6", "MAXWAITINGJOBS": "3", "RETRIALS": "0", "AUTOSUBMIT_VERSION": "3.15.0b", "OUTPUT": "pdf", "SAFETYSLEEPTIME": "1"}, "communications": {"API": "paramiko"}}, "proj": {"RUN": {"SIMULATION": "test-icon", "ENVIRONMENT": "CCE", "APPLICATION": "none", "MODEL_VERSION": "", "GRID": "r2b4", "MODEL": "icon"}}}');
INSERT INTO experiment_run VALUES(16,'2023-05-31-12:02:23','2023-05-31-12:02:54',1685527343,1685527374,'month',4,0,27,0,0,0,0,0,'{"platforms": {"moore": {"QUEUE": "serial", "PROJECT": "Earth", "SCRATCH_DIR": "/esarchive/scratch", "HOST": "moore", "USER": "", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "false"}, "ecmwf-cca": {"QUEUE": "np", "PROCESSORS_PER_NODE": "36", "PROJECT": "spesiccf", "SCRATCH_DIR": "/scratch/ms", "HOST": "cca", "VERSION": "pbs", "USER": "c3a", "TEST_SUITE": "True", "TYPE": "ecaccess", "ADD_PROJECT_TO_HOST": "false"}, "marenostrum3": {"QUEUE": "bsc_es", "PROCESSORS_PER_NODE": "16", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "mn", "TEST_SUITE": "True", "USER": "bsc32704", "TYPE": "lsf", "ADD_PROJECT_TO_HOST": "true"}, "marenostrum4": {"QUEUE": "bsc_es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "mn-bsc32", "USER": "", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "false"}, "lumi": {"QUEUE": "normal", "PROJECT": "project_465000454", "SCRATCH_DIR": "/scratch", "HOST": "lumi", "USER": "francerou", "TYPE": "slurm"}, "transfer_node": {"QUEUE": "serial", "PROJECT": "Earth", "SCRATCH_DIR": "/esarchive/scratch", "HOST": "bscearth000", "USER": "", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "false"}}, "jobs": {"OPA_2_2": {"EXCLUDE_CHUNKS": "1", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "DATA_NOTIFY[3:4]", "FILE": "CLEAN.sh"}, "OPA_2_1": {"EXCLUDE_CHUNKS": "1", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "DATA_NOTIFY", "FILE": "CLEAN.sh"}, "LOCAL_SETUP": {"PLATFORM": "LOCAL", "FILE": "LOCAL_SETUP.sh"}, "DATA_NOTIFY": {"SPLITS": "4", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "POST.sh"}, "OPA_1_1": {"EXCLUDE_CHUNKS": "2", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "DATA_NOTIFY[1:2]", "FILE": "CLEAN.sh"}, "OPA_1_2": {"EXCLUDE_CHUNKS": "2", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "DATA_NOTIFY[3:4]", "FILE": "CLEAN.sh"}, "MODEL_EVALUATION": {"PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "OPA_1_1", "FILE": "LOCALPOST.sh", "WALLCLOCK": "00:05"}, "INI": {"RUNNING": "member", "DEPENDENCIES": "REMOTE_SETUP", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "FILE": "INI.sh", "WALLCLOCK": "00:05"}, "REMOTE_SETUP": {"DEPENDENCIES": "LOCAL_SETUP", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "FILE": "REMOTE_SETUP.sh", "WALLCLOCK": "00:05"}, "DATA_CONSUMER_DN": {"EXCLUDE_CHUNKS": "1", "RUNNING": "chunk", "DEPENDENCIES": "DATA_NOTIFY", "FILE": "TRANSFER.sh", "PLATFORM": "LOCAL"}, "SIM": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "08:00", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "INI SIM-1", "THREADS": "1", "FILE": "SIM.sh"}, "DATA_CONSUMER_OPA": {"PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "OPA_1_1", "FILE": "TRANSFER.sh"}}, "exp": {"svn": {"HPCARCH": "LUMI", "EXPID": "a632", "PROJECT_REVISION": "", "PROJECT_URL": ""}, "git": {"HPCARCH": "LUMI", "EXPID": "a632", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "FETCH_SINGLE_BRANCH": "true", "PROJECT_SUBMODULES": "", "PROJECT_ORIGIN": ""}, "project": {"HPCARCH": "LUMI", "EXPID": "a632", "PROJECT_DESTINATION": "", "PROJECT_TYPE": "none"}, "experiment": {"RUN_ONLY_MEMBERS": "", "HPCARCH": "LUMI", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "4", "CHUNKINI": "", "NUMCHUNKS": "2", "DATELIST": "20000101", "EXPID": "a632", "MEMBERS": "fc0", "CALENDAR": "standard"}, "project_files": {"FILE_JOBS_CONF": "", "HPCARCH": "LUMI", "JOB_SCRIPTS_TYPE": "", "FILE_PROJECT_CONF": "", "EXPID": "a632"}, "rerun": {"HPCARCH": "LUMI", "CHUNKLIST": "", "EXPID": "a632", "RERUN": "FALSE"}, "local": {"EXPID": "a632", "HPCARCH": "LUMI", "PROJECT_PATH": "/esarchive/autosubmit/a62r/projj"}}, "conf": {"migrate": {"TO_USER": ""}, "mail": {"NOTIFICATIONS": "False", "TO": ""}, "storage": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "config": {"PRESUBMISSION": "FALSE", "EXPID": "a632", "TOTALJOBS": "6", "MAXWAITINGJOBS": "3", "RETRIALS": "0", "AUTOSUBMIT_VERSION": "3.15.0b", "OUTPUT": "pdf", "SAFETYSLEEPTIME": "1"}, "communications": {"API": "paramiko"}}, "proj": {"RUN": {"SIMULATION": "test-icon", "ENVIRONMENT": "CCE", "APPLICATION": "none", "MODEL_VERSION": "", "GRID": "r2b4", "MODEL": "icon"}}}');
INSERT INTO experiment_run VALUES(17,'2023-05-31-12:02:54','2023-05-31-12:03:04',1685527374,1685527384,'month',4,0,27,0,0,0,0,0,'{"platforms": {"moore": {"QUEUE": "serial", "PROJECT": "Earth", "SCRATCH_DIR": "/esarchive/scratch", "HOST": "moore", "USER": "", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "false"}, "ecmwf-cca": {"QUEUE": "np", "PROCESSORS_PER_NODE": "36", "PROJECT": "spesiccf", "SCRATCH_DIR": "/scratch/ms", "HOST": "cca", "VERSION": "pbs", "USER": "c3a", "TEST_SUITE": "True", "TYPE": "ecaccess", "ADD_PROJECT_TO_HOST": "false"}, "marenostrum3": {"QUEUE": "bsc_es", "PROCESSORS_PER_NODE": "16", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "mn", "TEST_SUITE": "True", "USER": "bsc32704", "TYPE": "lsf", "ADD_PROJECT_TO_HOST": "true"}, "marenostrum4": {"QUEUE": "bsc_es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "mn-bsc32", "USER": "", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "false"}, "lumi": {"QUEUE": "normal", "PROJECT": "project_465000454", "SCRATCH_DIR": "/scratch", "HOST": "lumi", "USER": "francerou", "TYPE": "slurm"}, "transfer_node": {"QUEUE": "serial", "PROJECT": "Earth", "SCRATCH_DIR": "/esarchive/scratch", "HOST": "bscearth000", "USER": "", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "false"}}, "jobs": {"OPA_2_2": {"EXCLUDE_CHUNKS": "1", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "DATA_NOTIFY[3:4]", "FILE": "CLEAN.sh"}, "OPA_2_1": {"EXCLUDE_CHUNKS": "1,2", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "FILE": "CLEAN.sh"}, "LOCAL_SETUP": {"PLATFORM": "LOCAL", "FILE": "LOCAL_SETUP.sh"}, "DATA_NOTIFY": {"SPLITS": "4", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "POST.sh"}, "OPA_1_1": {"EXCLUDE_CHUNKS": "2", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "DATA_NOTIFY[1:2]", "FILE": "CLEAN.sh"}, "OPA_1_2": {"EXCLUDE_CHUNKS": "2", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "DATA_NOTIFY[3:4]", "FILE": "CLEAN.sh"}, "MODEL_EVALUATION": {"PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "OPA_1_1", "FILE": "LOCALPOST.sh", "WALLCLOCK": "00:05"}, "INI": {"RUNNING": "member", "DEPENDENCIES": "REMOTE_SETUP", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "FILE": "INI.sh", "WALLCLOCK": "00:05"}, "REMOTE_SETUP": {"DEPENDENCIES": "LOCAL_SETUP", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "FILE": "REMOTE_SETUP.sh", "WALLCLOCK": "00:05"}, "DATA_CONSUMER_DN": {"EXCLUDE_CHUNKS": "1", "RUNNING": "chunk", "DEPENDENCIES": "DATA_NOTIFY", "FILE": "TRANSFER.sh", "PLATFORM": "LOCAL"}, "SIM": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "08:00", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "INI SIM-1", "THREADS": "1", "FILE": "SIM.sh"}, "DATA_CONSUMER_OPA": {"PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "OPA_1_1", "FILE": "TRANSFER.sh"}}, "exp": {"svn": {"HPCARCH": "LUMI", "EXPID": "a632", "PROJECT_REVISION": "", "PROJECT_URL": ""}, "git": {"HPCARCH": "LUMI", "EXPID": "a632", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "FETCH_SINGLE_BRANCH": "true", "PROJECT_SUBMODULES": "", "PROJECT_ORIGIN": ""}, "project": {"HPCARCH": "LUMI", "EXPID": "a632", "PROJECT_DESTINATION": "", "PROJECT_TYPE": "none"}, "experiment": {"RUN_ONLY_MEMBERS": "", "HPCARCH": "LUMI", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "4", "CHUNKINI": "", "NUMCHUNKS": "2", "DATELIST": "20000101", "EXPID": "a632", "MEMBERS": "fc0", "CALENDAR": "standard"}, "project_files": {"FILE_JOBS_CONF": "", "HPCARCH": "LUMI", "JOB_SCRIPTS_TYPE": "", "FILE_PROJECT_CONF": "", "EXPID": "a632"}, "rerun": {"HPCARCH": "LUMI", "CHUNKLIST": "", "EXPID": "a632", "RERUN": "FALSE"}, "local": {"EXPID": "a632", "HPCARCH": "LUMI", "PROJECT_PATH": "/esarchive/autosubmit/a62r/projj"}}, "conf": {"migrate": {"TO_USER": ""}, "mail": {"NOTIFICATIONS": "False", "TO": ""}, "storage": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "config": {"PRESUBMISSION": "FALSE", "EXPID": "a632", "TOTALJOBS": "6", "MAXWAITINGJOBS": "3", "RETRIALS": "0", "AUTOSUBMIT_VERSION": "3.15.0b", "OUTPUT": "pdf", "SAFETYSLEEPTIME": "1"}, "communications": {"API": "paramiko"}}, "proj": {"RUN": {"SIMULATION": "test-icon", "ENVIRONMENT": "CCE", "APPLICATION": "none", "MODEL_VERSION": "", "GRID": "r2b4", "MODEL": "icon"}}}');
INSERT INTO experiment_run VALUES(18,'2023-05-31-12:03:04','2023-05-31-12:03:18',1685527384,1685527398,'month',4,0,27,0,0,0,0,0,'{"platforms": {"moore": {"QUEUE": "serial", "PROJECT": "Earth", "SCRATCH_DIR": "/esarchive/scratch", "HOST": "moore", "USER": "", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "false"}, "ecmwf-cca": {"QUEUE": "np", "PROCESSORS_PER_NODE": "36", "PROJECT": "spesiccf", "SCRATCH_DIR": "/scratch/ms", "HOST": "cca", "VERSION": "pbs", "USER": "c3a", "TEST_SUITE": "True", "TYPE": "ecaccess", "ADD_PROJECT_TO_HOST": "false"}, "marenostrum3": {"QUEUE": "bsc_es", "PROCESSORS_PER_NODE": "16", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "mn", "TEST_SUITE": "True", "USER": "bsc32704", "TYPE": "lsf", "ADD_PROJECT_TO_HOST": "true"}, "marenostrum4": {"QUEUE": "bsc_es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "mn-bsc32", "USER": "", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "false"}, "lumi": {"QUEUE": "normal", "PROJECT": "project_465000454", "SCRATCH_DIR": "/scratch", "HOST": "lumi", "USER": "francerou", "TYPE": "slurm"}, "transfer_node": {"QUEUE": "serial", "PROJECT": "Earth", "SCRATCH_DIR": "/esarchive/scratch", "HOST": "bscearth000", "USER": "", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "false"}}, "jobs": {"OPA_2_2": {"EXCLUDE_CHUNKS": "1", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "DATA_NOTIFY[3:4]", "FILE": "CLEAN.sh"}, "OPA_2_1": {"EXCLUDE_CHUNKS": "1", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "FILE": "CLEAN.sh"}, "LOCAL_SETUP": {"PLATFORM": "LOCAL", "FILE": "LOCAL_SETUP.sh"}, "DATA_NOTIFY": {"SPLITS": "4", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "POST.sh"}, "OPA_1_1": {"EXCLUDE_CHUNKS": "2", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "DATA_NOTIFY[1:2]", "FILE": "CLEAN.sh"}, "OPA_1_2": {"EXCLUDE_CHUNKS": "2", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "DATA_NOTIFY[3:4]", "FILE": "CLEAN.sh"}, "MODEL_EVALUATION": {"PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "OPA_1_1", "FILE": "LOCALPOST.sh", "WALLCLOCK": "00:05"}, "INI": {"RUNNING": "member", "DEPENDENCIES": "REMOTE_SETUP", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "FILE": "INI.sh", "WALLCLOCK": "00:05"}, "REMOTE_SETUP": {"DEPENDENCIES": "LOCAL_SETUP", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "FILE": "REMOTE_SETUP.sh", "WALLCLOCK": "00:05"}, "DATA_CONSUMER_DN": {"EXCLUDE_CHUNKS": "1", "RUNNING": "chunk", "DEPENDENCIES": "DATA_NOTIFY", "FILE": "TRANSFER.sh", "PLATFORM": "LOCAL"}, "SIM": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "08:00", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "INI SIM-1", "THREADS": "1", "FILE": "SIM.sh"}, "DATA_CONSUMER_OPA": {"PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "OPA_1_1", "FILE": "TRANSFER.sh"}}, "exp": {"svn": {"HPCARCH": "LUMI", "EXPID": "a632", "PROJECT_REVISION": "", "PROJECT_URL": ""}, "git": {"HPCARCH": "LUMI", "EXPID": "a632", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "FETCH_SINGLE_BRANCH": "true", "PROJECT_SUBMODULES": "", "PROJECT_ORIGIN": ""}, "project": {"HPCARCH": "LUMI", "EXPID": "a632", "PROJECT_DESTINATION": "", "PROJECT_TYPE": "none"}, "experiment": {"RUN_ONLY_MEMBERS": "", "HPCARCH": "LUMI", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "4", "CHUNKINI": "", "NUMCHUNKS": "2", "DATELIST": "20000101", "EXPID": "a632", "MEMBERS": "fc0", "CALENDAR": "standard"}, "project_files": {"FILE_JOBS_CONF": "", "HPCARCH": "LUMI", "JOB_SCRIPTS_TYPE": "", "FILE_PROJECT_CONF": "", "EXPID": "a632"}, "rerun": {"HPCARCH": "LUMI", "CHUNKLIST": "", "EXPID": "a632", "RERUN": "FALSE"}, "local": {"EXPID": "a632", "HPCARCH": "LUMI", "PROJECT_PATH": "/esarchive/autosubmit/a62r/projj"}}, "conf": {"migrate": {"TO_USER": ""}, "mail": {"NOTIFICATIONS": "False", "TO": ""}, "storage": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "config": {"PRESUBMISSION": "FALSE", "EXPID": "a632", "TOTALJOBS": "6", "MAXWAITINGJOBS": "3", "RETRIALS": "0", "AUTOSUBMIT_VERSION": "3.15.0b", "OUTPUT": "pdf", "SAFETYSLEEPTIME": "1"}, "communications": {"API": "paramiko"}}, "proj": {"RUN": {"SIMULATION": "test-icon", "ENVIRONMENT": "CCE", "APPLICATION": "none", "MODEL_VERSION": "", "GRID": "r2b4", "MODEL": "icon"}}}');
INSERT INTO experiment_run VALUES(19,'2023-05-31-12:03:18','2023-05-31-12:03:39',1685527398,1685527419,'month',4,0,27,0,0,0,0,0,'{"platforms": {"moore": {"QUEUE": "serial", "PROJECT": "Earth", "SCRATCH_DIR": "/esarchive/scratch", "HOST": "moore", "USER": "", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "false"}, "ecmwf-cca": {"QUEUE": "np", "PROCESSORS_PER_NODE": "36", "PROJECT": "spesiccf", "SCRATCH_DIR": "/scratch/ms", "HOST": "cca", "VERSION": "pbs", "USER": "c3a", "TEST_SUITE": "True", "TYPE": "ecaccess", "ADD_PROJECT_TO_HOST": "false"}, "marenostrum3": {"QUEUE": "bsc_es", "PROCESSORS_PER_NODE": "16", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "mn", "TEST_SUITE": "True", "USER": "bsc32704", "TYPE": "lsf", "ADD_PROJECT_TO_HOST": "true"}, "marenostrum4": {"QUEUE": "bsc_es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "mn-bsc32", "USER": "", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "false"}, "lumi": {"QUEUE": "normal", "PROJECT": "project_465000454", "SCRATCH_DIR": "/scratch", "HOST": "lumi", "USER": "francerou", "TYPE": "slurm"}, "transfer_node": {"QUEUE": "serial", "PROJECT": "Earth", "SCRATCH_DIR": "/esarchive/scratch", "HOST": "bscearth000", "USER": "", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "false"}}, "jobs": {"OPA_2_2": {"EXCLUDE_CHUNKS": "1", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "DATA_NOTIFY[3:4]", "FILE": "CLEAN.sh"}, "OPA_2_1": {"PLATFORM": "LOCAL", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "EXCLUDE_CHUNK": "1", "RUNNING": "chunk", "FILE": "CLEAN.sh"}, "LOCAL_SETUP": {"PLATFORM": "LOCAL", "FILE": "LOCAL_SETUP.sh"}, "DATA_NOTIFY": {"SPLITS": "4", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "POST.sh"}, "OPA_1_1": {"EXCLUDE_CHUNKS": "2", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "DATA_NOTIFY[1:2]", "FILE": "CLEAN.sh"}, "OPA_1_2": {"EXCLUDE_CHUNKS": "2", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "DATA_NOTIFY[3:4]", "FILE": "CLEAN.sh"}, "MODEL_EVALUATION": {"PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "OPA_1_1", "FILE": "LOCALPOST.sh", "WALLCLOCK": "00:05"}, "INI": {"RUNNING": "member", "DEPENDENCIES": "REMOTE_SETUP", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "FILE": "INI.sh", "WALLCLOCK": "00:05"}, "REMOTE_SETUP": {"DEPENDENCIES": "LOCAL_SETUP", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "FILE": "REMOTE_SETUP.sh", "WALLCLOCK": "00:05"}, "DATA_CONSUMER_DN": {"EXCLUDE_CHUNKS": "1", "RUNNING": "chunk", "DEPENDENCIES": "DATA_NOTIFY", "FILE": "TRANSFER.sh", "PLATFORM": "LOCAL"}, "SIM": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "08:00", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "INI SIM-1", "THREADS": "1", "FILE": "SIM.sh"}, "DATA_CONSUMER_OPA": {"PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "OPA_1_1", "FILE": "TRANSFER.sh"}}, "exp": {"svn": {"HPCARCH": "LUMI", "EXPID": "a632", "PROJECT_REVISION": "", "PROJECT_URL": ""}, "git": {"HPCARCH": "LUMI", "EXPID": "a632", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "FETCH_SINGLE_BRANCH": "true", "PROJECT_SUBMODULES": "", "PROJECT_ORIGIN": ""}, "project": {"HPCARCH": "LUMI", "EXPID": "a632", "PROJECT_DESTINATION": "", "PROJECT_TYPE": "none"}, "experiment": {"RUN_ONLY_MEMBERS": "", "HPCARCH": "LUMI", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "4", "CHUNKINI": "", "NUMCHUNKS": "2", "DATELIST": "20000101", "EXPID": "a632", "MEMBERS": "fc0", "CALENDAR": "standard"}, "project_files": {"FILE_JOBS_CONF": "", "HPCARCH": "LUMI", "JOB_SCRIPTS_TYPE": "", "FILE_PROJECT_CONF": "", "EXPID": "a632"}, "rerun": {"HPCARCH": "LUMI", "CHUNKLIST": "", "EXPID": "a632", "RERUN": "FALSE"}, "local": {"EXPID": "a632", "HPCARCH": "LUMI", "PROJECT_PATH": "/esarchive/autosubmit/a62r/projj"}}, "conf": {"migrate": {"TO_USER": ""}, "mail": {"NOTIFICATIONS": "False", "TO": ""}, "storage": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "config": {"PRESUBMISSION": "FALSE", "EXPID": "a632", "TOTALJOBS": "6", "MAXWAITINGJOBS": "3", "RETRIALS": "0", "AUTOSUBMIT_VERSION": "3.15.0b", "OUTPUT": "pdf", "SAFETYSLEEPTIME": "1"}, "communications": {"API": "paramiko"}}, "proj": {"RUN": {"SIMULATION": "test-icon", "ENVIRONMENT": "CCE", "APPLICATION": "none", "MODEL_VERSION": "", "GRID": "r2b4", "MODEL": "icon"}}}');
INSERT INTO experiment_run VALUES(20,'2023-05-31-12:03:39','2023-05-31-12:03:48',1685527419,1685527428,'month',4,0,27,0,0,0,0,0,'{"platforms": {"moore": {"QUEUE": "serial", "PROJECT": "Earth", "SCRATCH_DIR": "/esarchive/scratch", "HOST": "moore", "USER": "", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "false"}, "ecmwf-cca": {"QUEUE": "np", "PROCESSORS_PER_NODE": "36", "PROJECT": "spesiccf", "SCRATCH_DIR": "/scratch/ms", "HOST": "cca", "VERSION": "pbs", "USER": "c3a", "TEST_SUITE": "True", "TYPE": "ecaccess", "ADD_PROJECT_TO_HOST": "false"}, "marenostrum3": {"QUEUE": "bsc_es", "PROCESSORS_PER_NODE": "16", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "mn", "TEST_SUITE": "True", "USER": "bsc32704", "TYPE": "lsf", "ADD_PROJECT_TO_HOST": "true"}, "marenostrum4": {"QUEUE": "bsc_es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "mn-bsc32", "USER": "", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "false"}, "lumi": {"QUEUE": "normal", "PROJECT": "project_465000454", "SCRATCH_DIR": "/scratch", "HOST": "lumi", "USER": "francerou", "TYPE": "slurm"}, "transfer_node": {"QUEUE": "serial", "PROJECT": "Earth", "SCRATCH_DIR": "/esarchive/scratch", "HOST": "bscearth000", "USER": "", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "false"}}, "jobs": {"OPA_2_2": {"EXCLUDE_CHUNKS": "1", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "DATA_NOTIFY[3:4]", "FILE": "CLEAN.sh"}, "OPA_2_1": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "RUNNING": "chunk", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "EXCLUDED_CHUNK": "1", "FILE": "CLEAN.sh"}, "LOCAL_SETUP": {"PLATFORM": "LOCAL", "FILE": "LOCAL_SETUP.sh"}, "DATA_NOTIFY": {"SPLITS": "4", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "POST.sh"}, "OPA_1_1": {"EXCLUDE_CHUNKS": "2", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "DATA_NOTIFY[1:2]", "FILE": "CLEAN.sh"}, "OPA_1_2": {"EXCLUDE_CHUNKS": "2", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "DATA_NOTIFY[3:4]", "FILE": "CLEAN.sh"}, "MODEL_EVALUATION": {"PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "OPA_1_1", "FILE": "LOCALPOST.sh", "WALLCLOCK": "00:05"}, "INI": {"RUNNING": "member", "DEPENDENCIES": "REMOTE_SETUP", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "FILE": "INI.sh", "WALLCLOCK": "00:05"}, "REMOTE_SETUP": {"DEPENDENCIES": "LOCAL_SETUP", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "FILE": "REMOTE_SETUP.sh", "WALLCLOCK": "00:05"}, "DATA_CONSUMER_DN": {"EXCLUDE_CHUNKS": "1", "RUNNING": "chunk", "DEPENDENCIES": "DATA_NOTIFY", "FILE": "TRANSFER.sh", "PLATFORM": "LOCAL"}, "SIM": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "08:00", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "INI SIM-1", "THREADS": "1", "FILE": "SIM.sh"}, "DATA_CONSUMER_OPA": {"PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "OPA_1_1", "FILE": "TRANSFER.sh"}}, "exp": {"svn": {"HPCARCH": "LUMI", "EXPID": "a632", "PROJECT_REVISION": "", "PROJECT_URL": ""}, "git": {"HPCARCH": "LUMI", "EXPID": "a632", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "FETCH_SINGLE_BRANCH": "true", "PROJECT_SUBMODULES": "", "PROJECT_ORIGIN": ""}, "project": {"HPCARCH": "LUMI", "EXPID": "a632", "PROJECT_DESTINATION": "", "PROJECT_TYPE": "none"}, "experiment": {"RUN_ONLY_MEMBERS": "", "HPCARCH": "LUMI", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "4", "CHUNKINI": "", "NUMCHUNKS": "2", "DATELIST": "20000101", "EXPID": "a632", "MEMBERS": "fc0", "CALENDAR": "standard"}, "project_files": {"FILE_JOBS_CONF": "", "HPCARCH": "LUMI", "JOB_SCRIPTS_TYPE": "", "FILE_PROJECT_CONF": "", "EXPID": "a632"}, "rerun": {"HPCARCH": "LUMI", "CHUNKLIST": "", "EXPID": "a632", "RERUN": "FALSE"}, "local": {"EXPID": "a632", "HPCARCH": "LUMI", "PROJECT_PATH": "/esarchive/autosubmit/a62r/projj"}}, "conf": {"migrate": {"TO_USER": ""}, "mail": {"NOTIFICATIONS": "False", "TO": ""}, "storage": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "config": {"PRESUBMISSION": "FALSE", "EXPID": "a632", "TOTALJOBS": "6", "MAXWAITINGJOBS": "3", "RETRIALS": "0", "AUTOSUBMIT_VERSION": "3.15.0b", "OUTPUT": "pdf", "SAFETYSLEEPTIME": "1"}, "communications": {"API": "paramiko"}}, "proj": {"RUN": {"SIMULATION": "test-icon", "ENVIRONMENT": "CCE", "APPLICATION": "none", "MODEL_VERSION": "", "GRID": "r2b4", "MODEL": "icon"}}}');
INSERT INTO experiment_run VALUES(21,'2023-05-31-12:03:48','2023-05-31-12:04:36',1685527428,1685527476,'month',4,0,26,0,0,0,0,0,'{"platforms": {"moore": {"QUEUE": "serial", "PROJECT": "Earth", "SCRATCH_DIR": "/esarchive/scratch", "HOST": "moore", "USER": "", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "false"}, "ecmwf-cca": {"QUEUE": "np", "PROCESSORS_PER_NODE": "36", "PROJECT": "spesiccf", "SCRATCH_DIR": "/scratch/ms", "HOST": "cca", "VERSION": "pbs", "USER": "c3a", "TEST_SUITE": "True", "TYPE": "ecaccess", "ADD_PROJECT_TO_HOST": "false"}, "marenostrum3": {"QUEUE": "bsc_es", "PROCESSORS_PER_NODE": "16", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "mn", "TEST_SUITE": "True", "USER": "bsc32704", "TYPE": "lsf", "ADD_PROJECT_TO_HOST": "true"}, "marenostrum4": {"QUEUE": "bsc_es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "mn-bsc32", "USER": "", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "false"}, "lumi": {"QUEUE": "normal", "PROJECT": "project_465000454", "SCRATCH_DIR": "/scratch", "HOST": "lumi", "USER": "francerou", "TYPE": "slurm"}, "transfer_node": {"QUEUE": "serial", "PROJECT": "Earth", "SCRATCH_DIR": "/esarchive/scratch", "HOST": "bscearth000", "USER": "", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "false"}}, "jobs": {"OPA_2_2": {"EXCLUDE_CHUNKS": "1", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "DATA_NOTIFY[3:4]", "FILE": "CLEAN.sh"}, "OPA_2_1": {"EXCLUDED_CHUNKS": "1", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "FILE": "CLEAN.sh"}, "LOCAL_SETUP": {"PLATFORM": "LOCAL", "FILE": "LOCAL_SETUP.sh"}, "DATA_NOTIFY": {"SPLITS": "4", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "POST.sh"}, "OPA_1_1": {"EXCLUDE_CHUNKS": "2", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "DATA_NOTIFY[1:2]", "FILE": "CLEAN.sh"}, "OPA_1_2": {"EXCLUDE_CHUNKS": "2", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "DATA_NOTIFY[3:4]", "FILE": "CLEAN.sh"}, "MODEL_EVALUATION": {"PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "OPA_1_1", "FILE": "LOCALPOST.sh", "WALLCLOCK": "00:05"}, "INI": {"RUNNING": "member", "DEPENDENCIES": "REMOTE_SETUP", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "FILE": "INI.sh", "WALLCLOCK": "00:05"}, "REMOTE_SETUP": {"DEPENDENCIES": "LOCAL_SETUP", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "FILE": "REMOTE_SETUP.sh", "WALLCLOCK": "00:05"}, "DATA_CONSUMER_DN": {"EXCLUDE_CHUNKS": "1", "RUNNING": "chunk", "DEPENDENCIES": "DATA_NOTIFY", "FILE": "TRANSFER.sh", "PLATFORM": "LOCAL"}, "SIM": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "08:00", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "INI SIM-1", "THREADS": "1", "FILE": "SIM.sh"}, "DATA_CONSUMER_OPA": {"PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "OPA_1_1", "FILE": "TRANSFER.sh"}}, "exp": {"svn": {"HPCARCH": "LUMI", "EXPID": "a632", "PROJECT_REVISION": "", "PROJECT_URL": ""}, "git": {"HPCARCH": "LUMI", "EXPID": "a632", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "FETCH_SINGLE_BRANCH": "true", "PROJECT_SUBMODULES": "", "PROJECT_ORIGIN": ""}, "project": {"HPCARCH": "LUMI", "EXPID": "a632", "PROJECT_DESTINATION": "", "PROJECT_TYPE": "none"}, "experiment": {"RUN_ONLY_MEMBERS": "", "HPCARCH": "LUMI", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "4", "CHUNKINI": "", "NUMCHUNKS": "2", "DATELIST": "20000101", "EXPID": "a632", "MEMBERS": "fc0", "CALENDAR": "standard"}, "project_files": {"FILE_JOBS_CONF": "", "HPCARCH": "LUMI", "JOB_SCRIPTS_TYPE": "", "FILE_PROJECT_CONF": "", "EXPID": "a632"}, "rerun": {"HPCARCH": "LUMI", "CHUNKLIST": "", "EXPID": "a632", "RERUN": "FALSE"}, "local": {"EXPID": "a632", "HPCARCH": "LUMI", "PROJECT_PATH": "/esarchive/autosubmit/a62r/projj"}}, "conf": {"migrate": {"TO_USER": ""}, "mail": {"NOTIFICATIONS": "False", "TO": ""}, "storage": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "config": {"PRESUBMISSION": "FALSE", "EXPID": "a632", "TOTALJOBS": "6", "MAXWAITINGJOBS": "3", "RETRIALS": "0", "AUTOSUBMIT_VERSION": "3.15.0b", "OUTPUT": "pdf", "SAFETYSLEEPTIME": "1"}, "communications": {"API": "paramiko"}}, "proj": {"RUN": {"SIMULATION": "test-icon", "ENVIRONMENT": "CCE", "APPLICATION": "none", "MODEL_VERSION": "", "GRID": "r2b4", "MODEL": "icon"}}}');
INSERT INTO experiment_run VALUES(22,'2023-05-31-12:04:36','2023-07-10-08:38:24',1685527476,1688971104,'month',4,0,25,0,0,0,0,0,'{"platforms": {"moore": {"QUEUE": "serial", "PROJECT": "Earth", "SCRATCH_DIR": "/esarchive/scratch", "HOST": "moore", "USER": "", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "false"}, "ecmwf-cca": {"QUEUE": "np", "PROCESSORS_PER_NODE": "36", "PROJECT": "spesiccf", "SCRATCH_DIR": "/scratch/ms", "HOST": "cca", "VERSION": "pbs", "USER": "c3a", "TEST_SUITE": "True", "TYPE": "ecaccess", "ADD_PROJECT_TO_HOST": "false"}, "marenostrum3": {"QUEUE": "bsc_es", "PROCESSORS_PER_NODE": "16", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "mn", "TEST_SUITE": "True", "USER": "bsc32704", "TYPE": "lsf", "ADD_PROJECT_TO_HOST": "true"}, "marenostrum4": {"QUEUE": "bsc_es", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "mn-bsc32", "USER": "", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "false"}, "lumi": {"QUEUE": "normal", "PROJECT": "project_465000454", "SCRATCH_DIR": "/scratch", "HOST": "lumi", "USER": "francerou", "TYPE": "slurm"}, "transfer_node": {"QUEUE": "serial", "PROJECT": "Earth", "SCRATCH_DIR": "/esarchive/scratch", "HOST": "bscearth000", "USER": "", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "false"}}, "jobs": {"OPA_2_2": {"EXCLUDE_CHUNKS": "1", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "DATA_NOTIFY[3:4]", "FILE": "CLEAN.sh"}, "OPA_2_1": {"EXCLUDED_CHUNKS": "1", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "FILE": "CLEAN.sh"}, "LOCAL_SETUP": {"PLATFORM": "LOCAL", "FILE": "LOCAL_SETUP.sh"}, "DATA_NOTIFY": {"SPLITS": "4", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "POST.sh"}, "OPA_1_1": {"EXCLUDE_CHUNKS": "2", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "DATA_NOTIFY[1:2]", "FILE": "CLEAN.sh"}, "OPA_1_2": {"EXCLUDED_CHUNKS": "2", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "00:05", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "DATA_NOTIFY[3:4]", "FILE": "CLEAN.sh"}, "MODEL_EVALUATION": {"PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "OPA_1_1", "FILE": "LOCALPOST.sh", "WALLCLOCK": "00:05"}, "INI": {"RUNNING": "member", "DEPENDENCIES": "REMOTE_SETUP", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "FILE": "INI.sh", "WALLCLOCK": "00:05"}, "REMOTE_SETUP": {"DEPENDENCIES": "LOCAL_SETUP", "CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "FILE": "REMOTE_SETUP.sh", "WALLCLOCK": "00:05"}, "DATA_CONSUMER_DN": {"EXCLUDE_CHUNKS": "1", "RUNNING": "chunk", "DEPENDENCIES": "DATA_NOTIFY", "FILE": "TRANSFER.sh", "PLATFORM": "LOCAL"}, "SIM": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -p standard\"]", "WALLCLOCK": "08:00", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "INI SIM-1", "THREADS": "1", "FILE": "SIM.sh"}, "DATA_CONSUMER_OPA": {"PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "OPA_1_1", "FILE": "TRANSFER.sh"}}, "exp": {"svn": {"HPCARCH": "LUMI", "EXPID": "a632", "PROJECT_REVISION": "", "PROJECT_URL": ""}, "git": {"HPCARCH": "LUMI", "EXPID": "a632", "PROJECT_BRANCH": "", "PROJECT_COMMIT": "", "FETCH_SINGLE_BRANCH": "true", "PROJECT_SUBMODULES": "", "PROJECT_ORIGIN": ""}, "project": {"HPCARCH": "LUMI", "EXPID": "a632", "PROJECT_DESTINATION": "", "PROJECT_TYPE": "none"}, "experiment": {"RUN_ONLY_MEMBERS": "", "HPCARCH": "LUMI", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "4", "CHUNKINI": "", "NUMCHUNKS": "2", "DATELIST": "20000101", "EXPID": "a632", "MEMBERS": "fc0", "CALENDAR": "standard"}, "project_files": {"FILE_JOBS_CONF": "", "HPCARCH": "LUMI", "JOB_SCRIPTS_TYPE": "", "FILE_PROJECT_CONF": "", "EXPID": "a632"}, "rerun": {"HPCARCH": "LUMI", "CHUNKLIST": "", "EXPID": "a632", "RERUN": "FALSE"}, "local": {"EXPID": "a632", "HPCARCH": "LUMI", "PROJECT_PATH": "/esarchive/autosubmit/a62r/projj"}}, "conf": {"migrate": {"TO_USER": ""}, "mail": {"NOTIFICATIONS": "False", "TO": ""}, "storage": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "config": {"PRESUBMISSION": "FALSE", "EXPID": "a632", "TOTALJOBS": "6", "MAXWAITINGJOBS": "3", "RETRIALS": "0", "AUTOSUBMIT_VERSION": "3.15.0b", "OUTPUT": "pdf", "SAFETYSLEEPTIME": "1"}, "communications": {"API": "paramiko"}}, "proj": {"RUN": {"SIMULATION": "test-icon", "ENVIRONMENT": "CCE", "APPLICATION": "none", "MODEL_VERSION": "", "GRID": "r2b4", "MODEL": "icon"}}}');
INSERT INTO experiment_run VALUES(23,'2023-07-10-08:38:24','2023-07-10-08:39:38',1688971104,1688971178,'month',1,0,40,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": "3", "TOTALJOBS": "20", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"CLEAN": {"FILE": "autosubmit/templates/clean.sh", "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "autosubmit/templates/remote_setup.sh", "DEPENDENCIES": {"CLEAN": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "ADDITIONAL_FILES": []}, "REMOTE_INIDATA": {"FILE": "autosubmit/templates/INI.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "CLEAN": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "REMOTE_COMPILATION": {"FILE": "autosubmit/templates/compilation.sh", "DEPENDENCIES": {"REMOTE_INIDATA": {}}, "RUNNING": "member", "PROCESSORS": "4", "WALLCLOCK": "00:50", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "PREPARE_TESTS": {"FILE": "autosubmit/templates/Tests.sh", "DEPENDENCIES": {"REMOTE_COMPILATION": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "FUNCTIONS_DIR": {"FILE": "autosubmit/templates/functions_dir.sh", "DEPENDENCIES": {"SCALABILITY_192": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "SCALABILITY_96": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "SCALABILITY_48": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "PROCESSORS": "192", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "SCALABILITY_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "SCALABILITY_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "SCALABILITY_192": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "SCALABILITY_768": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 768, "ADDITIONAL_FILES": []}, "SCALABILITY_1024": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 1024, "ADDITIONAL_FILES": []}, "TRACE_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "TRACE_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "TRACE_192": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "OSU_RUN_48": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "OSU_RUN_96": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "OSU_RUN_192": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "STREAM_1": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 1, "ADDITIONAL_FILES": []}, "STREAM_2": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 2, "ADDITIONAL_FILES": []}, "STREAM_4": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 4, "ADDITIONAL_FILES": []}, "STREAM_8": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 8, "ADDITIONAL_FILES": []}, "STREAM_16": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 16, "ADDITIONAL_FILES": []}, "STREAM_32": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 32, "ADDITIONAL_FILES": []}, "STREAM_48": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM0": {"TYPE": "ps", "HOST": "mn0.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "MAXWAITINGJOBS": "100", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es,mn2.bsc.es,mn3.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "MAXWAITINGJOBS": "100", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "bsc_es"}}, "EXPERIMENT": {"DATELIST": "20210811", "MEMBERS": "CompilationEfficiency HardwareBenchmarks WeakScaling StrongScaling", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-performance-profiling"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/ces/automatic_performance_profiling.git", "PROJECT_BRANCH": "autosubmit-makefile1", "PROJECT_COMMIT": ""}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "COMMON": {"GIT_REPO": "automatic_performance_profile", "REFRESH_GIT_REPO": "false", "MODEL": "nemo", "BRANCH_LIST": "avoid_error_partition", "CONFIGURATION": "BENCH", "EXP_ROOT": "%CURRENT_ROOTDIR%", "RUN_FOLDER": "hardware_benchmarks compilation_efficiency strong_scaling weakscaling", "TRACE_N_FUNCTIONS": "80"}, "COMMON_PATH_LOCATIONS": {"PROJECT_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%", "INIDATA_ROOT": "%CURRENT_ROOTDIR%/inidata", "BINARIES_ROOT": "%CURRENT_ROOTDIR%/bin", "RUN_ROOT": "%CURRENT_ROOTDIR%/run", "COMPILATION_ROOT": "%CURRENT_ROOTDIR%/compilation"}, "PARAMETERS_ENV_CONFIG": {"CONVERT_PARAM_FILE": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/target/ConvertParamFile.py", "CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations", "ENV_SOURCES": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/env/MN4/environment.env"}, "PROJECT_FLAGS": {"MODEL_CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%", "ENABLE_HW_BENCHMARKS": "false", "ENABLE_STRONGSCALING": "true", "ENABLE_WEAKSCALING": "false", "ENABLE_COMPILATION_EFFICIENCY": "false", "ENABLED_TESTS": "false false true false"}, "HW_BENCHMARKS": {"HW_BENCHMARKS_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/hardware_benchmarks"}, "STRONGSCALING": {"STRONGSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/strongscaling"}, "WEAKSCALING": {"WEAKSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/weakscaling"}, "COMPILATION_EFFICIENCY": {"COMPILATION_EFFICIENCY_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/compilation_efficiency"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a001", "PROJDIR": "/home/dbeltran/new_autosubmit/a001/proj/project_files", "DEFAULT": {"EXPID": "a67r", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a001/proj/auto-performance-profiling/autosubmit/configuration/common/,/home/dbeltran/new_autosubmit/a001/proj/auto-performance-profiling/autosubmit/configuration/preset-1/", "POST": "~/platforms_credentials.yml"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms_credentials.yml"}}');
INSERT INTO experiment_run VALUES(24,'2023-07-10-08:39:38','2023-07-10-08:40:40',1688971178,1688971240,'month',1,0,40,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": "3", "TOTALJOBS": "20", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"CLEAN": {"FILE": "autosubmit/templates/clean.sh", "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "autosubmit/templates/remote_setup.sh", "DEPENDENCIES": {"CLEAN": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "ADDITIONAL_FILES": []}, "REMOTE_INIDATA": {"FILE": "autosubmit/templates/INI.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "CLEAN": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "REMOTE_COMPILATION": {"FILE": "autosubmit/templates/compilation.sh", "DEPENDENCIES": {"REMOTE_INIDATA": {}}, "RUNNING": "member", "PROCESSORS": "4", "WALLCLOCK": "00:50", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "PREPARE_TESTS": {"FILE": "autosubmit/templates/Tests.sh", "DEPENDENCIES": {"REMOTE_COMPILATION": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "FUNCTIONS_DIR": {"FILE": "autosubmit/templates/functions_dir.sh", "DEPENDENCIES": {"SCALABILITY_192": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "SCALABILITY_96": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "SCALABILITY_48": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "PROCESSORS": "192", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "SCALABILITY_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "SCALABILITY_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "SCALABILITY_192": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "SCALABILITY_768": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 768, "ADDITIONAL_FILES": []}, "SCALABILITY_1024": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 1024, "ADDITIONAL_FILES": []}, "TRACE_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "TRACE_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "TRACE_192": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "OSU_RUN_48": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "OSU_RUN_96": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "OSU_RUN_192": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "STREAM_1": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 1, "ADDITIONAL_FILES": []}, "STREAM_2": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 2, "ADDITIONAL_FILES": []}, "STREAM_4": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 4, "ADDITIONAL_FILES": []}, "STREAM_8": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 8, "ADDITIONAL_FILES": []}, "STREAM_16": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 16, "ADDITIONAL_FILES": []}, "STREAM_32": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 32, "ADDITIONAL_FILES": []}, "STREAM_48": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM0": {"TYPE": "ps", "HOST": "mn0.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "MAXWAITINGJOBS": "100", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es,mn2.bsc.es,mn3.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "MAXWAITINGJOBS": "100", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "bsc_es"}}, "EXPERIMENT": {"DATELIST": "20210811", "MEMBERS": "CompilationEfficiency HardwareBenchmarks WeakScaling StrongScaling", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-performance-profiling"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/ces/automatic_performance_profiling.git", "PROJECT_BRANCH": "autosubmit-makefile1", "PROJECT_COMMIT": ""}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "COMMON": {"GIT_REPO": "automatic_performance_profile", "REFRESH_GIT_REPO": "false", "MODEL": "nemo", "BRANCH_LIST": "avoid_error_partition", "CONFIGURATION": "BENCH", "EXP_ROOT": "%CURRENT_ROOTDIR%", "RUN_FOLDER": "hardware_benchmarks compilation_efficiency strong_scaling weakscaling", "TRACE_N_FUNCTIONS": "80"}, "COMMON_PATH_LOCATIONS": {"PROJECT_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%", "INIDATA_ROOT": "%CURRENT_ROOTDIR%/inidata", "BINARIES_ROOT": "%CURRENT_ROOTDIR%/bin", "RUN_ROOT": "%CURRENT_ROOTDIR%/run", "COMPILATION_ROOT": "%CURRENT_ROOTDIR%/compilation"}, "PARAMETERS_ENV_CONFIG": {"CONVERT_PARAM_FILE": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/target/ConvertParamFile.py", "CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations", "ENV_SOURCES": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/env/MN4/environment.env"}, "PROJECT_FLAGS": {"MODEL_CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%", "ENABLE_HW_BENCHMARKS": "false", "ENABLE_STRONGSCALING": "true", "ENABLE_WEAKSCALING": "false", "ENABLE_COMPILATION_EFFICIENCY": "false", "ENABLED_TESTS": "false false true false"}, "HW_BENCHMARKS": {"HW_BENCHMARKS_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/hardware_benchmarks"}, "STRONGSCALING": {"STRONGSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/strongscaling"}, "WEAKSCALING": {"WEAKSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/weakscaling"}, "COMPILATION_EFFICIENCY": {"COMPILATION_EFFICIENCY_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/compilation_efficiency"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a001", "PROJDIR": "/home/dbeltran/new_autosubmit/a001/proj/project_files", "DEFAULT": {"EXPID": "a67r", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a001/proj/auto-performance-profiling/autosubmit/configuration/common/,/home/dbeltran/new_autosubmit/a001/proj/auto-performance-profiling/autosubmit/configuration/preset-1/", "POST": "~/platforms_credentials.yml"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms_credentials.yml"}}');
INSERT INTO experiment_run VALUES(25,'2023-07-10-08:40:40','2023-07-10-08:40:40',1688971240,0,'month',1,0,40,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.0b", "MAXWAITINGJOBS": "3", "TOTALJOBS": "20", "SAFETYSLEEPTIME": "10", "RETRIALS": 0, "OUTPUT": "pdf", "PRESUBMISSION": "FALSE"}, "JOBS": {"CLEAN": {"FILE": "autosubmit/templates/clean.sh", "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "autosubmit/templates/remote_setup.sh", "DEPENDENCIES": {"CLEAN": {}}, "RUNNING": "once", "WALLCLOCK": "00:30", "QUEUE": "debug", "PLATFORM": "marenostrum0", "CHECK": "true", "ADDITIONAL_FILES": []}, "REMOTE_INIDATA": {"FILE": "autosubmit/templates/INI.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "CLEAN": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "CHECK": "true", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "REMOTE_COMPILATION": {"FILE": "autosubmit/templates/compilation.sh", "DEPENDENCIES": {"REMOTE_INIDATA": {}}, "RUNNING": "member", "PROCESSORS": "4", "WALLCLOCK": "00:50", "NOTIFY_ON": "FAILED", "CUSTOM_DIRECTIVES": "[''#SBATCH -p interactive'']", "PLATFORM": "marenostrum0", "ADDITIONAL_FILES": []}, "PREPARE_TESTS": {"FILE": "autosubmit/templates/Tests.sh", "DEPENDENCIES": {"REMOTE_COMPILATION": {}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "FUNCTIONS_DIR": {"FILE": "autosubmit/templates/functions_dir.sh", "DEPENDENCIES": {"SCALABILITY_192": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "SCALABILITY_96": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}, "SCALABILITY_48": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "PROCESSORS": "192", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "ADDITIONAL_FILES": []}, "SCALABILITY_48": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "SCALABILITY_96": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "SCALABILITY_192": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "WEAKSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "SCALABILITY_768": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 768, "ADDITIONAL_FILES": []}, "SCALABILITY_1024": {"FILE": "autosubmit/templates/scalability.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}, "STRONGSCALING, COMPILATIONEFFICIENCY": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 1024, "ADDITIONAL_FILES": []}, "TRACE_48": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "TRACE_96": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "TRACE_192": {"FILE": "autosubmit/templates/extrae.sh", "DEPENDENCIES": {"FUNCTIONS_DIR": {"MEMBERS_FROM": {"HARDWAREBENCHMARKS, COMPILATIONEFFICIENCY": {"MEMBERS_TO": "None", "CHUNKS_TO": "None", "DATES_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "02:00", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "OSU_RUN_48": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}, "OSU_RUN_96": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 96, "ADDITIONAL_FILES": []}, "OSU_RUN_192": {"FILE": "autosubmit/templates/osu_run.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 192, "ADDITIONAL_FILES": []}, "STREAM_1": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 1, "ADDITIONAL_FILES": []}, "STREAM_2": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 2, "ADDITIONAL_FILES": []}, "STREAM_4": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 4, "ADDITIONAL_FILES": []}, "STREAM_8": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 8, "ADDITIONAL_FILES": []}, "STREAM_16": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 16, "ADDITIONAL_FILES": []}, "STREAM_32": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 32, "ADDITIONAL_FILES": []}, "STREAM_48": {"FILE": "autosubmit/templates/stream.sh", "DEPENDENCIES": {"PREPARE_TESTS": {"MEMBERS_FROM": {"COMPILATIONEFFICIENCY, WEAKSCALING, STRONGSCALING": {"DATES_TO": "None", "MEMBERS_TO": "None", "CHUNKS_TO": "None"}}}}, "RUNNING": "member", "WALLCLOCK": "00:30", "QUEUE": "debug", "CHECK": "true", "NOTIFY_ON": "FAILED", "PROCESSORS": 48, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM0": {"TYPE": "ps", "HOST": "mn0.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "MAXWAITINGJOBS": "100", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch"}, "MARENOSTRUM4": {"TYPE": "slurm", "HOST": "mn1.bsc.es,mn2.bsc.es,mn3.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "MAXWAITINGJOBS": "100", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "bsc_es"}}, "EXPERIMENT": {"DATELIST": "20210811", "MEMBERS": "CompilationEfficiency HardwareBenchmarks WeakScaling StrongScaling", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-performance-profiling"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/ces/automatic_performance_profiling.git", "PROJECT_BRANCH": "autosubmit-makefile1", "PROJECT_COMMIT": ""}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": "FALSE", "CHUNKLIST": ""}, "COMMON": {"GIT_REPO": "automatic_performance_profile", "REFRESH_GIT_REPO": "false", "MODEL": "nemo", "BRANCH_LIST": "avoid_error_partition", "CONFIGURATION": "BENCH", "EXP_ROOT": "%CURRENT_ROOTDIR%", "RUN_FOLDER": "hardware_benchmarks compilation_efficiency strong_scaling weakscaling", "TRACE_N_FUNCTIONS": "80"}, "COMMON_PATH_LOCATIONS": {"PROJECT_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%", "INIDATA_ROOT": "%CURRENT_ROOTDIR%/inidata", "BINARIES_ROOT": "%CURRENT_ROOTDIR%/bin", "RUN_ROOT": "%CURRENT_ROOTDIR%/run", "COMPILATION_ROOT": "%CURRENT_ROOTDIR%/compilation"}, "PARAMETERS_ENV_CONFIG": {"CONVERT_PARAM_FILE": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/target/ConvertParamFile.py", "CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations", "ENV_SOURCES": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/cfg/env/MN4/environment.env"}, "PROJECT_FLAGS": {"MODEL_CONFIG_FOLDER": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%", "ENABLE_HW_BENCHMARKS": "false", "ENABLE_STRONGSCALING": "true", "ENABLE_WEAKSCALING": "false", "ENABLE_COMPILATION_EFFICIENCY": "false", "ENABLED_TESTS": "false false true false"}, "HW_BENCHMARKS": {"HW_BENCHMARKS_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/hardware_benchmarks"}, "STRONGSCALING": {"STRONGSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/strongscaling"}, "WEAKSCALING": {"WEAKSCALING_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/weakscaling"}, "COMPILATION_EFFICIENCY": {"COMPILATION_EFFICIENCY_PARAMETERS_ROOT": "%CURRENT_ROOTDIR%/%COMMON.GIT_REPO%/configurations/model/%COMMON.MODEL%/MultiExperiment/compilation_efficiency"}, "MAIL": {"NOTIFICATIONS": false, "TO": ""}, "COMMUNICATIONS": {"API": "paramiko"}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": "True"}, "MIGRATE": {"TO_USER": ""}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a001", "PROJDIR": "/home/dbeltran/new_autosubmit/a001/proj/project_files", "DEFAULT": {"EXPID": "a67r", "HPCARCH": "marenostrum4", "CUSTOM_CONFIG": {"PRE": "/home/dbeltran/new_autosubmit/a001/proj/auto-performance-profiling/autosubmit/configuration/common/,/home/dbeltran/new_autosubmit/a001/proj/auto-performance-profiling/autosubmit/configuration/preset-1/", "POST": "~/platforms_credentials.yml"}}, "AS_TEMP": {"FILENAME_TO_LOAD": "/home/dbeltran/platforms_credentials.yml"}}');
CREATE TABLE job_data (
      id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
      counter INTEGER NOT NULL,
      job_name TEXT NOT NULL,
      created TEXT NOT NULL,
      modified TEXT NOT NULL,
      submit INTEGER NOT NULL,
      start INTEGER NOT NULL,
      finish INTEGER NOT NULL,
      status TEXT NOT NULL,
      rowtype INTEGER NOT NULL,
      ncpus INTEGER NOT NULL,
      wallclock TEXT NOT NULL,
      qos TEXT NOT NULL,
      energy INTEGER NOT NULL,
      date TEXT NOT NULL,
      section TEXT NOT NULL,
      member TEXT NOT NULL,
      chunk INTEGER NOT NULL,
      last INTEGER NOT NULL,
      platform TEXT NOT NULL,
      job_id INTEGER NOT NULL,
      extra_data TEXT NOT NULL,
      nnodes INTEGER NOT NULL DEFAULT 0,
      run_id INTEGER,
      MaxRSS REAL NOT NULL DEFAULT 0.0,
      AveRSS REAL NOT NULL DEFAULT 0.0,
      out TEXT NOT NULL,
      err TEXT NOT NULL,
      rowstatus INTEGER NOT NULL DEFAULT 0,
      children TEXT,
      platform_output TEXT,
      UNIQUE(counter,job_name)
      );
DELETE FROM sqlite_sequence;
INSERT INTO sqlite_sequence VALUES('experiment_run',25);
CREATE INDEX ID_JOB_NAME ON job_data(job_name);
COMMIT;
